Re: [dpdk-dev] [PATCH] app/testpmd: fix IP checksum calculation

2020-12-04 Thread Ferruh Yigit

On 12/3/2020 1:59 PM, George Prekas wrote:

Insert a compiler barrier to make sure that the IP checksum calculation
happens after setting all the fields of the IP header.



Can you please provide the compiler details, and if there is any specific 
instruction on how to reproduce this failure?



Signed-off-by: George Prekas 
---
  app/test-pmd/flowgen.c | 1 +
  1 file changed, 1 insertion(+)

diff --git a/app/test-pmd/flowgen.c b/app/test-pmd/flowgen.c
index acf3e2460..893b4b0b8 100644
--- a/app/test-pmd/flowgen.c
+++ b/app/test-pmd/flowgen.c
@@ -150,6 +150,7 @@ pkt_burst_flow_gen(struct fwd_stream *fs)
   next_flow);
ip_hdr->total_length = RTE_CPU_TO_BE_16(pkt_size -
   sizeof(*eth_hdr));
+   rte_compiler_barrier();
ip_hdr->hdr_checksum = ip_sum((unaligned_uint16_t *)ip_hdr,
 sizeof(*ip_hdr));
  





Re: [dpdk-dev] [PATCH 0/5] add apistats function

2020-12-04 Thread Ferruh Yigit

On 12/4/2020 7:51 AM, Hideyuki Yamashita wrote:

In general, DPDK application consumes CPU usage because it polls
incoming packets using rx_burst API in infinite loop.
This makes difficult to estimate how much CPU usage is really
used to send/receive packets by the DPDK application.

For example, even if no incoming packets arriving, CPU usage
looks nearly 100% when observed by top command.

It is beneficial if developers can observe real CPU usage of the
DPDK application.
Such information can be exported to monitoring application like
prometheus/graphana and shows CPU usage graphically.

To achieve above, this patch set provides apistats functionality.
apistats provides the followiing two counters for each lcore.
- rx_burst_counts[RTE_MAX_LCORE]
- tx_burst_counts[RTE_MAX_LCORE]
Those accumulates rx_burst/tx_burst counts since the application starts.

By using those values, developers can roughly estimate CPU usage.
Let us assume a DPDK application is simply forwarding packets.
It calls tx_burst only if it receive packets.
If rx_burst_counts=1000 and tx_burst_count=1000 during certain
period of time, one can assume CPU usage is 100%.
If rx_burst_counts=1000 and tx_burst_count=100 during certain
period of time, one can assume CPU usage is 10%.
Here we assumes that tx_burst_count equals counts which rx_burst function
really receives incoming packets.


This patch set provides the following.
- basic API counting functionality(apistats) into librte_ethdev
- add code to testpmd to accumulate counter information
- add code to proc-info to retrieve above mentioned counter information
- add description in proc-info document about --apistats parameter
- modify MAINTAINERS file for apistats.c and apistats.h

Hideyuki Yamashita (5):
   maintainers: update maintainers file for apistats
   app/proc-info: add to use apistats
   app/test-pmd: add to use apistats
   docs: add description of apistats parameter into proc-info
   librte_ethdev: add to use apistats

  MAINTAINERS  |  3 ++
  app/proc-info/main.c | 46 +++
  app/test-pmd/testpmd.c   |  4 ++
  doc/guides/tools/proc_info.rst   | 10 -
  lib/librte_ethdev/meson.build|  6 ++-
  lib/librte_ethdev/rte_apistats.c | 64 
  lib/librte_ethdev/rte_apistats.h | 64 
  lib/librte_ethdev/rte_ethdev.h   |  7 
  lib/librte_ethdev/version.map|  5 +++
  9 files changed, 205 insertions(+), 4 deletions(-)
  create mode 100644 lib/librte_ethdev/rte_apistats.c
  create mode 100644 lib/librte_ethdev/rte_apistats.h



cc'ed Dave Hunt. As far as I remember he did something for same goal in the 
past, but in a different way, he can comment better.


Re: [dpdk-dev] Printfs in Signal Handler

2020-12-04 Thread prateekag

Ok.

On 2020-12-03 02:11, Thomas Monjalon wrote:

01/12/2020 10:24, Thomas Monjalon:

01/12/2020 04:39, prateekag:
> printf is not signal safe and may lead to deadlock if kept in signal handler
> and
> signal comes in two quick succession. It will not lead to incorrect behavior
> and it is a highly unlikely event. And an expert may understand why this
> issue happened. Is it worthwhile to change these printfs to unix I/O write
> call?

Thank you for reporting.
Please could you describe which files and functions you are talking about?


I've received a private reply:
Filenames:
testpmd.c
test_pmd_perf.c
evt_main.c
pdump/main.c
Function name:
signal_handler


I am OK with removing these printfs.

Do you want to do the patch with the explanation?


Re: [dpdk-dev] Printfs in Signal Handler

2020-12-04 Thread prateekag

Hi,

I can only look at this problem a week later, If someone wants to correct 
this, they may go ahead. The problem is how to convert an integer to string 
and what functions to use to create the final string. "itoa" is not a part of 
C standard, writing custom itoa may pollute the code. strcpy is asyc-safe 
afaik.
The strings in which signal number is not required to printed can be directly 
converted to write call.


Prateek Agarwal


On 2020-12-03 02:11, Thomas Monjalon wrote:

01/12/2020 10:24, Thomas Monjalon:

01/12/2020 04:39, prateekag:
> printf is not signal safe and may lead to deadlock if kept in signal handler
> and
> signal comes in two quick succession. It will not lead to incorrect behavior
> and it is a highly unlikely event. And an expert may understand why this
> issue happened. Is it worthwhile to change these printfs to unix I/O write
> call?

Thank you for reporting.
Please could you describe which files and functions you are talking about?


I've received a private reply:
Filenames:
testpmd.c
test_pmd_perf.c
evt_main.c
pdump/main.c
Function name:
signal_handler


I am OK with removing these printfs.

Do you want to do the patch with the explanation?


Re: [dpdk-dev] Printfs in Signal Handler

2020-12-04 Thread Thomas Monjalon
04/12/2020 10:20, prateekag:
> Hi,
> 
> I can only look at this problem a week later, If someone wants to correct 
> this, they may go ahead. The problem is how to convert an integer to string 
> and what functions to use to create the final string. "itoa" is not a part of 
> C standard, writing custom itoa may pollute the code. strcpy is asyc-safe 
> afaik.
> The strings in which signal number is not required to printed can be directly 
> converted to write call.

First question is to decide whether the prints are useful enough
to be kept?


> On 2020-12-03 02:11, Thomas Monjalon wrote:
> > 01/12/2020 10:24, Thomas Monjalon:
> >> 01/12/2020 04:39, prateekag:
> >> > printf is not signal safe and may lead to deadlock if kept in signal 
> >> > handler
> >> > and
> >> > signal comes in two quick succession. It will not lead to incorrect 
> >> > behavior
> >> > and it is a highly unlikely event. And an expert may understand why this
> >> > issue happened. Is it worthwhile to change these printfs to unix I/O 
> >> > write
> >> > call?
> >> 
> >> Thank you for reporting.
> >> Please could you describe which files and functions you are talking about?
> > 
> > I've received a private reply:
> > Filenames:
> > testpmd.c
> > test_pmd_perf.c
> > evt_main.c
> > pdump/main.c
> > Function name:
> > signal_handler
> > 
> > 
> > I am OK with removing these printfs.
> > 
> > Do you want to do the patch with the explanation?
> 







[dpdk-dev] [PATCH] net/bnxt: use FUNC_QCFG cmd to retrieve allocated resources for PF

2020-12-04 Thread Somnath Kotur
This cmd should be called by every driver after 'hwrm_func_cfg'
to get the actual number of resources allocated by the HWRM.
The values returned in the cmd are the max values for that PF.

Also, now that the max values for the PF are computed in probe itself,
no need to invoke FUNC_QCAPs or any other cmd in dev_configure_op()
as that would just override the actual max values obtained above.

Fixes: f8168ca0e69 ("net/bnxt:  support thor controller")
Cc: sta...@dpdk.org

Signed-off-by: Somnath Kotur 
---
 drivers/net/bnxt/bnxt_ethdev.c |  7 ---
 drivers/net/bnxt/bnxt_hwrm.c   | 36 +-
 2 files changed, 35 insertions(+), 8 deletions(-)

diff --git a/drivers/net/bnxt/bnxt_ethdev.c b/drivers/net/bnxt/bnxt_ethdev.c
index 81c8f8d79d..0de8867bd6 100644
--- a/drivers/net/bnxt/bnxt_ethdev.c
+++ b/drivers/net/bnxt/bnxt_ethdev.c
@@ -1060,13 +1060,6 @@ static int bnxt_dev_configure_op(struct rte_eth_dev 
*eth_dev)
}
 
pthread_mutex_unlock(&bp->def_cp_lock);
-   } else {
-   /* legacy driver needs to get updated values */
-   rc = bnxt_hwrm_func_qcaps(bp);
-   if (rc) {
-   PMD_DRV_LOG(ERR, "hwrm func qcaps fail:%d\n", rc);
-   return rc;
-   }
}
 
/* Inherit new configurations */
diff --git a/drivers/net/bnxt/bnxt_hwrm.c b/drivers/net/bnxt/bnxt_hwrm.c
index 24c33185b4..147d5ef5df 100644
--- a/drivers/net/bnxt/bnxt_hwrm.c
+++ b/drivers/net/bnxt/bnxt_hwrm.c
@@ -3455,6 +3455,35 @@ static int bnxt_update_max_resources(struct bnxt *bp,
return 0;
 }
 
+/* Update the PF resource values based on how many resources
+ * got allocated to it.
+ */
+static int bnxt_update_max_resources_pf_only(struct bnxt *bp)
+{
+   struct hwrm_func_qcfg_input req = {0};
+   struct hwrm_func_qcfg_output *resp = bp->hwrm_cmd_resp_addr;
+   int rc;
+
+   /* Get the actual allocated values now */
+   HWRM_PREP(&req, HWRM_FUNC_QCFG, BNXT_USE_CHIMP_MB);
+   req.fid = rte_cpu_to_le_16(0x);
+   rc = bnxt_hwrm_send_message(bp, &req, sizeof(req), BNXT_USE_CHIMP_MB);
+   HWRM_CHECK_RESULT();
+
+   bp->max_rsscos_ctx = rte_le_to_cpu_16(resp->alloc_rsscos_ctx);
+   bp->max_stat_ctx = rte_le_to_cpu_16(resp->alloc_stat_ctx);
+   bp->max_cp_rings = rte_le_to_cpu_16(resp->alloc_cmpl_rings);
+   bp->max_tx_rings = rte_le_to_cpu_16(resp->alloc_tx_rings);
+   bp->max_rx_rings = rte_le_to_cpu_16(resp->alloc_rx_rings);
+   bp->max_l2_ctx = rte_le_to_cpu_16(resp->alloc_l2_ctx);
+   bp->max_ring_grps = rte_le_to_cpu_16(resp->alloc_hw_ring_grps);
+   bp->max_vnics = rte_le_to_cpu_16(resp->alloc_vnics);
+
+   HWRM_UNLOCK();
+
+   return 0;
+}
+
 int bnxt_hwrm_func_qcfg_current_vf_vlan(struct bnxt *bp, int vf)
 {
struct hwrm_func_qcfg_input req = {0};
@@ -3554,8 +3583,13 @@ int bnxt_hwrm_allocate_pf_only(struct bnxt *bp)
  HWRM_FUNC_CFG_INPUT_FLAGS_STD_TX_RING_MODE_DISABLE);
bp->pf->func_cfg_flags |=
HWRM_FUNC_CFG_INPUT_FLAGS_STD_TX_RING_MODE_DISABLE;
+
rc = bnxt_hwrm_pf_func_cfg(bp, &pf_resc);
-   rc = __bnxt_hwrm_func_qcaps(bp);
+   if (rc)
+   return rc;
+
+   rc = bnxt_update_max_resources_pf_only(bp);
+
return rc;
 }
 
-- 
2.28.0.497.g54e85e7



Re: [dpdk-dev] [PATCH 0/5] add apistats function

2020-12-04 Thread David Hunt



On 4/12/2020 7:51 AM, Hideyuki Yamashita wrote:

In general, DPDK application consumes CPU usage because it polls
incoming packets using rx_burst API in infinite loop.
This makes difficult to estimate how much CPU usage is really
used to send/receive packets by the DPDK application.

For example, even if no incoming packets arriving, CPU usage
looks nearly 100% when observed by top command.

It is beneficial if developers can observe real CPU usage of the
DPDK application.
Such information can be exported to monitoring application like
prometheus/graphana and shows CPU usage graphically.

To achieve above, this patch set provides apistats functionality.
apistats provides the followiing two counters for each lcore.
- rx_burst_counts[RTE_MAX_LCORE]
- tx_burst_counts[RTE_MAX_LCORE]
Those accumulates rx_burst/tx_burst counts since the application starts.

By using those values, developers can roughly estimate CPU usage.
Let us assume a DPDK application is simply forwarding packets.
It calls tx_burst only if it receive packets.
If rx_burst_counts=1000 and tx_burst_count=1000 during certain
period of time, one can assume CPU usage is 100%.
If rx_burst_counts=1000 and tx_burst_count=100 during certain
period of time, one can assume CPU usage is 10%.
Here we assumes that tx_burst_count equals counts which rx_burst function
really receives incoming packets.


This patch set provides the following.
- basic API counting functionality(apistats) into librte_ethdev
- add code to testpmd to accumulate counter information
- add code to proc-info to retrieve above mentioned counter information
- add description in proc-info document about --apistats parameter
- modify MAINTAINERS file for apistats.c and apistats.h

Hideyuki Yamashita (5):
   maintainers: update maintainers file for apistats
   app/proc-info: add to use apistats
   app/test-pmd: add to use apistats
   docs: add description of apistats parameter into proc-info
   librte_ethdev: add to use apistats

  MAINTAINERS  |  3 ++
  app/proc-info/main.c | 46 +++
  app/test-pmd/testpmd.c   |  4 ++
  doc/guides/tools/proc_info.rst   | 10 -
  lib/librte_ethdev/meson.build|  6 ++-
  lib/librte_ethdev/rte_apistats.c | 64 
  lib/librte_ethdev/rte_apistats.h | 64 
  lib/librte_ethdev/rte_ethdev.h   |  7 
  lib/librte_ethdev/version.map|  5 +++
  9 files changed, 205 insertions(+), 4 deletions(-)
  create mode 100644 lib/librte_ethdev/rte_apistats.c
  create mode 100644 lib/librte_ethdev/rte_apistats.h



Hi Hideyuki,

I have a few questions on the patch set.

How does this compare to the mechanism added to l3fwd-power which counts 
the number of empty, partial and full polls, and uses them to calculate 
busyness? We saw pretty good tracking of busyness using those metrics. I 
would be concerned that just looking at the numebr of rx_bursts and 
tx_bursts may be limited to only a few use-cases. The l3fwd-power 
example uses branchless increments to capture empty, non-empty, full, 
and non-full polls.


Why not use the existing telemetry library to store the stats? It would 
be good if whatever metrics were counted were made available in a 
standard way, so that external entities such as collectd could pick them 
up, rather than having to parse the new struct. The l3fwd-power example 
registers the necessary new metrics, and exposes them through the 
telemetry library.


And a comment on the patch set in general: The order of the patch set 
seems reversed. The earlier patch do not compile, because they depend on 
rte_apistats.h, which is introduced in the final patch. Each patch as it 
is applied needs to build successfully.


Also, I would suggest a different name. rte_apistats seems very generic 
and could apply to anything. How about something like rte_ethdev_stats.h 
or rte_burst_stats.h?


Rgds,
Dave.









[dpdk-dev] Minutes of Technical Board Meeting, 2020-12-02

2020-12-04 Thread Maxime Coquelin
Minutes of Technical Board Meeting, 2020-12-2

Members Attending
-
- Ferruh
- Kevin
- Bruce
- Konstantin
- Thomas
- Hemant
- Maxime (Chair)
- Olivier
- Jerin
- Honnappa

NOTE: The technical board meetings every second Wednesday on Jitsi [0]
at 3pm UTC. Meetings are public and DPDK community members  are welcome
to attend.

NOTE: Next meeting will be on Wednesday 2020-12-16 @3pm UTC, and will be
chaired by Olivier.

1) DPDK build configuration - Future enhancements
=
* AR to Bruce to create initial version of the design document.

2) Asia DPDK event updates
==
* English version of the CFP is ready. Translation in Mandarin on-going.
* Sessions moderators
 - AR to Techboard members to contact their Mandarin-speaking colleagues
   who could be interested in moderating sessions.
 - 4 moderators would be needed.

3) v20.11 LTS Maintainership

* Kevin appointed maintainer for v20.11 LTS.



[dpdk-dev] DPDK secondary process access to mbufs using rte_pktmbuf_attach_extbuf()

2020-12-04 Thread Pranab Das
Hi

I am wondering if the secondary DPDK processes can access  the mbufs that are 
attached using rte_pktmbuf_attach_extbuf().
The DPDK primary process allocates the buffer pool from the heap.  Is there any 
example application that you can refer to ?

Thank you very much


  *   PKDas


[dpdk-dev] [Bug 591] atlantic APIs is missing input validation

2020-12-04 Thread bugzilla
https://bugs.dpdk.org/show_bug.cgi?id=591

Bug ID: 591
   Summary: atlantic APIs is missing input validation
   Product: DPDK
   Version: unspecified
  Hardware: All
OS: All
Status: UNCONFIRMED
  Severity: normal
  Priority: Normal
 Component: ethdev
  Assignee: dev@dpdk.org
  Reporter: ferruh.yi...@intel.com
  Target Milestone: ---

* rte_pmd_atl_macsec_config_txsc(uint16_t port, uint8_t *mac)
  - 'mac' is used without NULL check

* rte_pmd_atl_macsec_config_rxsc(uint16_t port, uint8_t *mac, uint16_t pi) 
  - 'mac' is used without NULL check

* rte_pmd_atl_macsec_select_txsa(uint16_t port, uint8_t idx, uint8_t an,
 uint32_t pn, uint8_t *key)
  - 'key' is used without NULL check

* rte_pmd_atl_macsec_select_rxsa(uint16_t port, uint8_t idx, uint8_t an,
 uint32_t pn, uint8_t *key)
  - 'key' is used without NULL check

-- 
You are receiving this mail because:
You are the assignee for the bug.

[dpdk-dev] [Bug 592] bnxt PMD APIs is missing input validation

2020-12-04 Thread bugzilla
https://bugs.dpdk.org/show_bug.cgi?id=592

Bug ID: 592
   Summary: bnxt PMD APIs is missing input validation
   Product: DPDK
   Version: unspecified
  Hardware: All
OS: All
Status: UNCONFIRMED
  Severity: normal
  Priority: Normal
 Component: ethdev
  Assignee: dev@dpdk.org
  Reporter: ferruh.yi...@intel.com
  Target Milestone: ---

* int rte_pmd_bnxt_mac_addr_add(uint16_t port, struct rte_ether_addr *addr,
uint32_t vf_id)
  - 'addr' is used without NULL check

-- 
You are receiving this mail because:
You are the assignee for the bug.

[dpdk-dev] [Bug 593] dpaa2 PMD APIs is missing input validation

2020-12-04 Thread bugzilla
https://bugs.dpdk.org/show_bug.cgi?id=593

Bug ID: 593
   Summary: dpaa2 PMD APIs is missing input validation
   Product: DPDK
   Version: unspecified
  Hardware: All
OS: All
Status: UNCONFIRMED
  Severity: normal
  Priority: Normal
 Component: ethdev
  Assignee: dev@dpdk.org
  Reporter: ferruh.yi...@intel.com
  Target Milestone: ---

1)
struct rte_flow *
rte_pmd_dpaa2_mux_flow_create(uint32_t dpdmux_id,
  struct rte_flow_item *pattern[],
  struct rte_flow_action *actions[])

'- 'pattern' & 'actions' & 'pattern[0]' & 'actions[0]', should be checked
against NULL before using them


2)
int
rte_pmd_dpaa2_set_custom_hash(uint16_t port_id,
  uint16_t offset,
  uint8_t size)

- 'port_id' should be checked if it is valid and if it is 'dpaa2' port or not

-- 
You are receiving this mail because:
You are the assignee for the bug.

[dpdk-dev] [Bug 594] i40e PMD APIs is missing input validation

2020-12-04 Thread bugzilla
https://bugs.dpdk.org/show_bug.cgi?id=594

Bug ID: 594
   Summary: i40e PMD APIs is missing input validation
   Product: DPDK
   Version: unspecified
  Hardware: All
OS: All
Status: UNCONFIRMED
  Severity: normal
  Priority: Normal
 Component: ethdev
  Assignee: dev@dpdk.org
  Reporter: ferruh.yi...@intel.com
  Target Milestone: ---

1)
int
rte_pmd_i40e_add_vf_mac_addr(uint16_t port, uint16_t vf_id,
 struct rte_ether_addr *mac_addr)

- 'mac_addr' is used without NULL check

2)
int rte_pmd_i40e_flow_add_del_packet_template(
uint16_t port,
const struct rte_pmd_i40e_pkt_template_conf *conf,
uint8_t add)

- 'conf' is used without NULL check

-- 
You are receiving this mail because:
You are the assignee for the bug.

[dpdk-dev] [PATCH v2 1/2] ci: hook to GitHub Actions

2020-12-04 Thread David Marchand
With the recent changes in terms of free access to the Travis CI, let's
offer an alternative with GitHub Actions.
Running jobs on ARM is not supported unless using external runners, so
this commit only adds builds for x86_64 and cross compiling for i386 and
aarch64.

Differences with the Travis CI integration:
- Error logs are not dumped to the console when something goes wrong.
  Instead, they are gathered in a "catch-all" step and attached as
  artifacts.
- A cache entry is stored once and for all, but if no cache is found you
  can inherit from the default branch cache. The cache is 5GB large, for
  the whole git repository.
- The maximum retention of logs and artifacts is 3 months.
- /home/runner is world writable, so a workaround has been added for
  starting dpdk processes.
- Ilya, working on OVS GHA support, noticed that jobs can run with
  processors that don't have the same capabilities. For DPDK, this
  impacts the ccache content since everything was built with
  -march=native so far, and we will end up with binaries that can't run
  in a later build. The problem has not been seen in Travis CI (?) but
  it is safer to use a fixed "-Dmachine=default" in any case.
- Scheduling jobs is part of the configuration and takes the form of a
  crontab. A build is scheduled every Monday at 0:00 (UTC) to provide a
  default ccache for the week (useful for the ovsrobot).

Signed-off-by: David Marchand 
---
Changelog since v1:
- changed shell variables value in CI scripts and Travis configuration
  (s/=[^\$]*1/=\1true), this makes it easier for GHA,
- forced compilation as 'default' to avoid random unit tests issues in
  GHA,
- scheduled a run per week on Monday at 0:00 UTC,
- updated the ccache key:
  - no need to depend on the default-library parameter since this
parameter only impacts the linking of dpdk binaries,
  - the week when the cache is generated is added so that jobs in
other branches can benefit from a recent cache (mimicking what we had
for the robot in Travis),
- realigned documentation generation with what is done in Travis:
  generating the doc in all jobs was a waste of resources,

---
 .ci/linux-build.sh  |  17 +++---
 .github/workflows/build.yml | 100 
 .travis.yml |  24 -
 MAINTAINERS |   1 +
 4 files changed, 123 insertions(+), 19 deletions(-)
 create mode 100644 .github/workflows/build.yml

diff --git a/.ci/linux-build.sh b/.ci/linux-build.sh
index d079801d78..ee8d07f865 100755
--- a/.ci/linux-build.sh
+++ b/.ci/linux-build.sh
@@ -12,7 +12,9 @@ on_error() {
 fi
 done
 }
-trap on_error EXIT
+# We capture the error logs as artifacts in Github Actions, no need to dump
+# them via a EXIT handler.
+[ -n "$GITHUB_WORKFLOW" ] || trap on_error EXIT
 
 install_libabigail() {
 version=$1
@@ -28,16 +30,16 @@ install_libabigail() {
 rm ${version}.tar.gz
 }
 
-if [ "$AARCH64" = "1" ]; then
+if [ "$AARCH64" = "true" ]; then
 # convert the arch specifier
 OPTS="$OPTS --cross-file config/arm/arm64_armv8_linux_gcc"
 fi
 
-if [ "$BUILD_DOCS" = "1" ]; then
+if [ "$BUILD_DOCS" = "true" ]; then
 OPTS="$OPTS -Denable_docs=true"
 fi
 
-if [ "$BUILD_32BIT" = "1" ]; then
+if [ "$BUILD_32BIT" = "true" ]; then
 OPTS="$OPTS -Dc_args=-m32 -Dc_link_args=-m32"
 export PKG_CONFIG_LIBDIR="/usr/lib32/pkgconfig"
 fi
@@ -48,16 +50,17 @@ else
 OPTS="$OPTS -Dexamples=all"
 fi
 
+OPTS="$OPTS -Dmachine=default"
 OPTS="$OPTS --default-library=$DEF_LIB"
 OPTS="$OPTS --buildtype=debugoptimized"
 meson build --werror $OPTS
 ninja -C build
 
-if [ "$AARCH64" != "1" ]; then
+if [ "$AARCH64" != "true" ]; then
 devtools/test-null.sh
 fi
 
-if [ "$ABI_CHECKS" = "1" ]; then
+if [ "$ABI_CHECKS" = "true" ]; then
 LIBABIGAIL_VERSION=${LIBABIGAIL_VERSION:-libabigail-1.6}
 
 if [ "$(cat libabigail/VERSION 2>/dev/null)" != "$LIBABIGAIL_VERSION" ]; 
then
@@ -95,6 +98,6 @@ if [ "$ABI_CHECKS" = "1" ]; then
 devtools/check-abi.sh reference install ${ABI_CHECKS_WARN_ONLY:-}
 fi
 
-if [ "$RUN_TESTS" = "1" ]; then
+if [ "$RUN_TESTS" = "true" ]; then
 sudo meson test -C build --suite fast-tests -t 3
 fi
diff --git a/.github/workflows/build.yml b/.github/workflows/build.yml
new file mode 100644
index 00..bef6e52372
--- /dev/null
+++ b/.github/workflows/build.yml
@@ -0,0 +1,100 @@
+name: build
+
+on:
+  push:
+  schedule:
+- cron: '0 0 * * 1'
+
+defaults:
+  run:
+shell: bash --noprofile --norc -exo pipefail {0}
+
+jobs:
+  build:
+name: ${{ join(matrix.config.*, '-') }}
+runs-on: ${{ matrix.config.os }}
+env:
+  AARCH64: ${{ matrix.config.cross == 'aarch64' }}
+  BUILD_32BIT: ${{ matrix.config.cross == 'i386' }}
+  BUILD_DOCS: ${{ contains(matrix.config.checks, 'doc') }}
+  CC: ccache ${{ matrix.config.compiler }}
+  DEF_LIB: ${{ matrix.config.library }}
+  RUN_TESTS: ${{ contains(matrix.config.checks, 'tests') }}
+
+strategy:
+  fail-

[dpdk-dev] [PATCH v2 2/2] ci: enable v21 ABI checks

2020-12-04 Thread David Marchand
v21 ABI will be maintained until v21.11.

Let's use the latest released libabigail 1.8.

In GitHub Actions, libabigail binaries and the ABI reference are stored
in two shared caches as all branches can use the same.

While at it, we can reproduce changes from the commit 0b8086ce3fe7
("devtools: remove useless files from ABI reference").
This will save some space in the CI caches.

Signed-off-by: David Marchand 
---
 .ci/linux-build.sh  |  5 -
 .github/workflows/build.yml | 26 +-
 .travis.yml | 27 +++
 3 files changed, 56 insertions(+), 2 deletions(-)

diff --git a/.ci/linux-build.sh b/.ci/linux-build.sh
index ee8d07f865..d2c821adf3 100755
--- a/.ci/linux-build.sh
+++ b/.ci/linux-build.sh
@@ -86,10 +86,13 @@ if [ "$ABI_CHECKS" = "true" ]; then
 if [ ! -d reference ]; then
 refsrcdir=$(readlink -f $(pwd)/../dpdk-$REF_GIT_TAG)
 git clone --single-branch -b $REF_GIT_TAG $REF_GIT_REPO $refsrcdir
-meson --werror $OPTS $refsrcdir $refsrcdir/build
+meson $OPTS -Dexamples= $refsrcdir $refsrcdir/build
 ninja -C $refsrcdir/build
 DESTDIR=$(pwd)/reference ninja -C $refsrcdir/build install
 devtools/gen-abi.sh reference
+find reference/usr/local -name '*.a' -delete
+rm -rf reference/usr/local/bin
+rm -rf reference/usr/local/share
 echo $REF_GIT_TAG > reference/VERSION
 fi
 
diff --git a/.github/workflows/build.yml b/.github/workflows/build.yml
index bef6e52372..05eb59527f 100644
--- a/.github/workflows/build.yml
+++ b/.github/workflows/build.yml
@@ -15,10 +15,13 @@ jobs:
 runs-on: ${{ matrix.config.os }}
 env:
   AARCH64: ${{ matrix.config.cross == 'aarch64' }}
+  ABI_CHECKS: ${{ contains(matrix.config.checks, 'abi') }}
   BUILD_32BIT: ${{ matrix.config.cross == 'i386' }}
   BUILD_DOCS: ${{ contains(matrix.config.checks, 'doc') }}
   CC: ccache ${{ matrix.config.compiler }}
   DEF_LIB: ${{ matrix.config.library }}
+  LIBABIGAIL_VERSION: libabigail-1.8
+  REF_GIT_TAG: v20.11
   RUN_TESTS: ${{ contains(matrix.config.checks, 'tests') }}
 
 strategy:
@@ -31,7 +34,7 @@ jobs:
   - os: ubuntu-18.04
 compiler: gcc
 library: shared
-checks: doc+tests
+checks: abi+doc+tests
   - os: ubuntu-18.04
 compiler: clang
 library: static
@@ -60,6 +63,10 @@ jobs:
   run: |
 echo -n '::set-output name=ccache::'
 echo 'ccache-${{ matrix.config.os }}-${{ matrix.config.compiler }}-${{ 
matrix.config.cross }}-'$(date -u +%Y-w%W)
+echo -n '::set-output name=libabigail::'
+echo 'libabigail-${{ matrix.config.os }}'
+echo -n '::set-output name=abi::'
+echo 'abi-${{ matrix.config.os }}-${{ matrix.config.compiler }}-${{ 
matrix.config.cross }}-${{ env.LIBABIGAIL_VERSION }}-${{ env.REF_GIT_TAG }}'
 - name: Retrieve ccache cache
   uses: actions/cache@v2
   with:
@@ -67,10 +74,27 @@ jobs:
 key: ${{ steps.get_ref_keys.outputs.ccache }}-${{ github.ref }}
 restore-keys: |
   ${{ steps.get_ref_keys.outputs.ccache }}-refs/heads/main
+- name: Retrieve libabigail cache
+  id: libabigail-cache
+  uses: actions/cache@v2
+  if: env.ABI_CHECKS == 'true'
+  with:
+path: libabigail
+key: ${{ steps.get_ref_keys.outputs.libabigail }}
+- name: Retrieve ABI reference cache
+  uses: actions/cache@v2
+  if: env.ABI_CHECKS == 'true'
+  with:
+path: reference
+key: ${{ steps.get_ref_keys.outputs.abi }}
 - name: Install packages
   run: sudo apt install -y ccache libnuma-dev python3-setuptools
 python3-wheel python3-pip ninja-build libbsd-dev libpcap-dev
 libibverbs-dev libcrypto++-dev libfdt-dev libjansson-dev
+- name: Install libabigail build dependencies if no cache is available
+  if: env.ABI_CHECKS == 'true' && steps.libabigail-cache.outputs.cache-hit 
!= 'true'
+  run: sudo apt install -y autoconf automake libtool pkg-config libxml2-dev
+  libdw-dev
 - name: Install i386 cross compiling packages
   if: env.BUILD_32BIT == 'true'
   run: sudo apt install -y gcc-multilib
diff --git a/.travis.yml b/.travis.yml
index d655e286c3..5aa7ad49f1 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -2,6 +2,9 @@
 language: c
 cache:
   ccache: true
+  directories:
+- libabigail
+- reference
 
 dist: bionic
 
@@ -18,6 +21,9 @@ _aarch64_packages: &aarch64_packages
   - *required_packages
   - [gcc-aarch64-linux-gnu, libc6-dev-arm64-cross, 
pkg-config-aarch64-linux-gnu]
 
+_libabigail_build_packages: &libabigail_build_packages
+  - [autoconf, automake, libtool, pkg-config, libxml2-dev, libdw-dev]
+
 _build_32b_packages: &build_32b_packages
   - *required_packages
   - [gcc-multilib]
@@ -28,6 +34,11 @@ _doc_packages: &doc_packages
 before_install: ./.ci/${TRAVIS_OS_NAME}-s

[dpdk-dev] [PATCH] Remove printf from signal handler.

2020-12-04 Thread Prateek Agarwal
printf is not async-signal safe. Using printf in signal handlers may lead to 
deadlock. Removed printf from signal handlers present in several applications.

Signed-off-by: Prateek Agarwal 
---
 app/pdump/main.c | 2 --
 app/test-eventdev/evt_main.c | 4 
 app/test-flow-perf/main.c| 3 ---
 app/test-pmd/testpmd.c   | 2 --
 app/test/test_pmd_perf.c | 1 -
 5 files changed, 12 deletions(-)

diff --git a/app/pdump/main.c b/app/pdump/main.c
index b34bf3353..380f0ea0f 100644
--- a/app/pdump/main.c
+++ b/app/pdump/main.c
@@ -573,8 +573,6 @@ static void
 signal_handler(int sig_num)
 {
if (sig_num == SIGINT) {
-   printf("\n\nSignal %d received, preparing to exit...\n",
-   sig_num);
quit_signal = 1;
}
 }
diff --git a/app/test-eventdev/evt_main.c b/app/test-eventdev/evt_main.c
index a8d304bab..51d5897f8 100644
--- a/app/test-eventdev/evt_main.c
+++ b/app/test-eventdev/evt_main.c
@@ -22,12 +22,8 @@ signal_handler(int signum)
 {
int i;
static uint8_t once;
-
if ((signum == SIGINT || signum == SIGTERM) && !once) {
once = true;
-   printf("\nSignal %d received, preparing to exit...\n",
-   signum);
-
if (test != NULL) {
/* request all lcores to exit from the main loop */
*(int *)test->test_priv = true;
diff --git a/app/test-flow-perf/main.c b/app/test-flow-perf/main.c
index 03d01a8b5..aeb0ef3b0 100644
--- a/app/test-flow-perf/main.c
+++ b/app/test-flow-perf/main.c
@@ -1001,9 +1001,6 @@ static void
 signal_handler(int signum)
 {
if (signum == SIGINT || signum == SIGTERM) {
-   printf("\n\nSignal %d received, preparing to exit...\n",
-   signum);
-   printf("Error: Stats are wrong due to sudden signal!\n\n");
force_quit = true;
}
 }
diff --git a/app/test-pmd/testpmd.c b/app/test-pmd/testpmd.c
index 33fc0fddf..7ec87e7fd 100644
--- a/app/test-pmd/testpmd.c
+++ b/app/test-pmd/testpmd.c
@@ -3794,8 +3794,6 @@ static void
 signal_handler(int signum)
 {
if (signum == SIGINT || signum == SIGTERM) {
-   printf("\nSignal %d received, preparing to exit...\n",
-   signum);
 #ifdef RTE_LIB_PDUMP
/* uninitialize packet capture framework */
rte_pdump_uninit();
diff --git a/app/test/test_pmd_perf.c b/app/test/test_pmd_perf.c
index 4db816a36..58cb84401 100644
--- a/app/test/test_pmd_perf.c
+++ b/app/test/test_pmd_perf.c
@@ -319,7 +319,6 @@ signal_handler(int signum)
 {
/*  USR1 signal, stop testing */
if (signum == SIGUSR1) {
-   printf("Force Stop!\n");
stop = 1;
}
 
-- 
2.25.1



[dpdk-dev] [PATCH v3 0/9] net/ionic: minor updates and documentation

2020-12-04 Thread Andrew Boyer
These patches make some minor changes to the ionic PMD.

Signed-off-by: Andrew Boyer 

---
v3:
* Fixed up false-positives from codespell and gcc 8.3/9.3

v2:
* Address Ferruh's comments (thank you!)
* Switch to net/ionic: prefix
* Leave UNMAINTAINED flag for now
* Split patch 8 into patch 8 & 9; drop whitespace changes

Andrew Boyer (9):
  net/ionic: connect ionic to the build system
  net/ionic: update interface file to the latest version
  net/ionic: update documentation and MAINTAINERS
  net/ionic: check for cmd completion more frequently
  net/ionic: remove some unused fields
  net/ionic: convert 'deferred' boolean to a flag bit
  net/ionic: warn if loopback mode is requested
  net/ionic: minor refactorings and helper variables
  net/ionic: minor logging fixups

 MAINTAINERS|3 +-
 doc/guides/nics/features/ionic.ini |2 +
 doc/guides/nics/ionic.rst  |   13 +-
 drivers/net/ionic/ionic.h  |2 +-
 drivers/net/ionic/ionic_dev.c  |   10 +-
 drivers/net/ionic/ionic_dev.h  |   13 +-
 drivers/net/ionic/ionic_ethdev.c   |   14 +-
 drivers/net/ionic/ionic_if.h   | 1343 +++-
 drivers/net/ionic/ionic_lif.c  |  107 ++-
 drivers/net/ionic/ionic_lif.h  |4 +-
 drivers/net/ionic/ionic_mac_api.c  |4 +-
 drivers/net/ionic/ionic_main.c |   86 +-
 drivers/net/ionic/ionic_osdep.h|   10 -
 drivers/net/ionic/ionic_regs.h |9 -
 drivers/net/ionic/ionic_rxtx.c |   51 +-
 drivers/net/meson.build|1 +
 16 files changed, 1085 insertions(+), 587 deletions(-)

-- 
2.17.1



[dpdk-dev] [PATCH v3 1/9] net/ionic: connect ionic to the build system

2020-12-04 Thread Andrew Boyer
Otherwise the ionic PMD is never built.

Signed-off-by: Andrew Boyer 
---
 drivers/net/meson.build | 1 +
 1 file changed, 1 insertion(+)

diff --git a/drivers/net/meson.build b/drivers/net/meson.build
index 29f477750..6e4aa6bf3 100644
--- a/drivers/net/meson.build
+++ b/drivers/net/meson.build
@@ -26,6 +26,7 @@ drivers = ['af_packet',
'iavf',
'ice',
'igc',
+   'ionic',
'ipn3ke',
'ixgbe',
'kni',
diff --git a/drivers/net/ionic/ionic_dev.h b/drivers/net/ionic/ionic_dev.h
index 532255a60..dc64a6d28 100644
--- a/drivers/net/ionic/ionic_dev.h
+++ b/drivers/net/ionic/ionic_dev.h
@@ -20,7 +20,9 @@
 
 #define IONIC_LIFS_MAX 1024
 
-#define IONIC_DEVCMD_TIMEOUT   30 /* devcmd_timeout */
+#define IONIC_DEVCMD_TIMEOUT   5   /* devcmd_timeout */
+#define IONIC_DEVCMD_CHECK_PERIOD_US   10  /* devcmd status chk period */
+
 #defineIONIC_ALIGN 4096
 
 struct ionic_adapter;
diff --git a/drivers/net/ionic/ionic_main.c b/drivers/net/ionic/ionic_main.c
index 2ade213d2..f77bddaa4 100644
--- a/drivers/net/ionic/ionic_main.c
+++ b/drivers/net/ionic/ionic_main.c
@@ -144,12 +144,12 @@ static int
 ionic_wait_ctx_for_completion(struct ionic_lif *lif, struct ionic_qcq *qcq,
struct ionic_admin_ctx *ctx, unsigned long max_wait)
 {
-   unsigned long step_msec = 1;
-   unsigned int max_wait_msec = max_wait * 1000;
-   unsigned long elapsed_msec = 0;
+   unsigned long step_usec = IONIC_DEVCMD_CHECK_PERIOD_US;
+   unsigned long max_wait_usec = max_wait * 100L;
+   unsigned long elapsed_usec = 0;
int budget = 8;
 
-   while (ctx->pending_work && elapsed_msec < max_wait_msec) {
+   while (ctx->pending_work && elapsed_usec < max_wait_usec) {
/*
 * Locking here as adminq is served inline (this could be called
 * from multiple places)
@@ -160,8 +160,8 @@ ionic_wait_ctx_for_completion(struct ionic_lif *lif, struct 
ionic_qcq *qcq,
 
rte_spinlock_unlock(&lif->adminq_service_lock);
 
-   msec_delay(step_msec);
-   elapsed_msec += step_msec;
+   rte_delay_us_block(step_usec);
+   elapsed_usec += step_usec;
}
 
return (!ctx->pending_work);
@@ -195,9 +195,9 @@ ionic_adminq_post_wait(struct ionic_lif *lif, struct 
ionic_admin_ctx *ctx)
 static int
 ionic_dev_cmd_wait(struct ionic_dev *idev, unsigned long max_wait)
 {
-   unsigned long step_msec = 100;
-   unsigned int max_wait_msec = max_wait * 1000;
-   unsigned long elapsed_msec = 0;
+   unsigned long step_usec = IONIC_DEVCMD_CHECK_PERIOD_US;
+   unsigned long max_wait_usec = max_wait * 100L;
+   unsigned long elapsed_usec = 0;
int done;
 
/* Wait for dev cmd to complete.. but no more than max_wait sec */
@@ -205,20 +205,20 @@ ionic_dev_cmd_wait(struct ionic_dev *idev, unsigned long 
max_wait)
do {
done = ionic_dev_cmd_done(idev);
if (done) {
-   IONIC_PRINT(DEBUG, "DEVCMD %d done took %ld msecs",
-   idev->dev_cmd->cmd.cmd.opcode,
-   elapsed_msec);
+   IONIC_PRINT(DEBUG, "DEVCMD %d done took %ld usecs",
+   ioread8(&idev->dev_cmd->cmd.cmd.opcode),
+   elapsed_usec);
return 0;
}
 
-   msec_delay(step_msec);
+   rte_delay_us_block(step_usec);
 
-   elapsed_msec += step_msec;
-   } while (elapsed_msec < max_wait_msec);
+   elapsed_usec += step_usec;
+   } while (elapsed_usec < max_wait_usec);
 
-   IONIC_PRINT(DEBUG, "DEVCMD %d timeout after %ld msecs",
-   idev->dev_cmd->cmd.cmd.opcode,
-   elapsed_msec);
+   IONIC_PRINT(ERR, "DEVCMD %d timeout after %ld usecs",
+   ioread8(&idev->dev_cmd->cmd.cmd.opcode),
+   elapsed_usec);
 
return -ETIMEDOUT;
 }
diff --git a/drivers/net/ionic/ionic_osdep.h b/drivers/net/ionic/ionic_osdep.h
index e04bb8f65..a55d59918 100644
--- a/drivers/net/ionic/ionic_osdep.h
+++ b/drivers/net/ionic/ionic_osdep.h
@@ -20,13 +20,8 @@
 
 #include "ionic_logs.h"
 
-#define DELAY(x) rte_delay_us(x)
-#define usec_delay(x) DELAY(x)
-#define msec_delay(x) DELAY(1000 * (x))
-
 #define BIT(nr)(1UL << (nr))
 #define BIT_ULL(nr)(1ULL << (nr))
-#define BITS_TO_LONGS(nr)  div_round_up(nr, 8 * sizeof(long))
 
 #ifndef PAGE_SHIFT
 #define PAGE_SHIFT  12
@@ -44,11 +39,6 @@ typedef uint16_t __le16;
 typedef uint32_t __le32;
 typedef uint64_t __le64;
 
-static inline uint32_t div_round_up(uint32_t n, uint32_t d)
-{
-   return (n + d - 1) / d;
-}
-
 #define ioread8(reg)   rte_read8(reg)
 #define ioread32(reg)  rte_read32(reg)
 #define iowrite8(value, reg)   rte_write8(value, reg)
-- 
2.17.1



[dpdk-dev] [PATCH v3 5/9] net/ionic: remove some unused fields

2020-12-04 Thread Andrew Boyer
This conserves resources.

Signed-off-by: Andrew Boyer 
---
 drivers/net/ionic/ionic.h|  1 -
 drivers/net/ionic/ionic_dev.c|  5 +
 drivers/net/ionic/ionic_dev.h|  7 +--
 drivers/net/ionic/ionic_ethdev.c |  2 --
 drivers/net/ionic/ionic_lif.c| 22 ++
 drivers/net/ionic/ionic_lif.h|  2 --
 drivers/net/ionic/ionic_regs.h   |  6 --
 7 files changed, 8 insertions(+), 37 deletions(-)

diff --git a/drivers/net/ionic/ionic.h b/drivers/net/ionic/ionic.h
index 1538df309..a93110326 100644
--- a/drivers/net/ionic/ionic.h
+++ b/drivers/net/ionic/ionic.h
@@ -59,7 +59,6 @@ struct ionic_adapter {
uint32_t link_speed;
uint32_t nintrs;
bool intrs[IONIC_INTR_CTRL_REGS_MAX];
-   bool is_mgmt_nic;
bool link_up;
char fw_version[IONIC_DEVINFO_FWVERS_BUFLEN];
struct rte_pci_device *pci_dev;
diff --git a/drivers/net/ionic/ionic_dev.c b/drivers/net/ionic/ionic_dev.c
index 5c2820b7a..fc68f5c74 100644
--- a/drivers/net/ionic/ionic_dev.c
+++ b/drivers/net/ionic/ionic_dev.c
@@ -65,7 +65,6 @@ ionic_dev_setup(struct ionic_adapter *adapter)
}
 
idev->db_pages = bar->vaddr;
-   idev->phy_db_pages = bar->bus_addr;
 
return 0;
 }
@@ -343,7 +342,6 @@ ionic_dev_cmd_adminq_init(struct ionic_dev *idev,
.q_init.type = q->type,
.q_init.index = q->index,
.q_init.flags = IONIC_QINIT_F_ENA,
-   .q_init.pid = q->pid,
.q_init.intr_index = intr_index,
.q_init.ring_size = rte_log2_u32(q->num_descs),
.q_init.ring_base = q->base_pa,
@@ -419,7 +417,7 @@ ionic_cq_service(struct ionic_cq *cq, uint32_t work_to_do,
 int
 ionic_q_init(struct ionic_lif *lif, struct ionic_dev *idev,
 struct ionic_queue *q, uint32_t index, uint32_t num_descs,
-size_t desc_size, size_t sg_desc_size, uint32_t pid)
+size_t desc_size, size_t sg_desc_size)
 {
uint32_t ring_size;
 
@@ -439,7 +437,6 @@ ionic_q_init(struct ionic_lif *lif, struct ionic_dev *idev,
q->sg_desc_size = sg_desc_size;
q->head_idx = 0;
q->tail_idx = 0;
-   q->pid = pid;
 
return 0;
 }
diff --git a/drivers/net/ionic/ionic_dev.h b/drivers/net/ionic/ionic_dev.h
index dc64a6d28..7150f7f2c 100644
--- a/drivers/net/ionic/ionic_dev.h
+++ b/drivers/net/ionic/ionic_dev.h
@@ -120,10 +120,7 @@ struct ionic_dev {
union ionic_dev_cmd_regs __iomem *dev_cmd;
 
struct ionic_doorbell __iomem *db_pages;
-   rte_iova_t phy_db_pages;
-
struct ionic_intr __iomem *intr_ctrl;
-
struct ionic_intr_status __iomem *intr_status;
 
struct ionic_port_info *port_info;
@@ -163,11 +160,9 @@ struct ionic_queue {
uint32_t num_descs;
uint32_t desc_size;
uint32_t sg_desc_size;
-   uint32_t pid;
uint32_t qid;
uint32_t qtype;
struct ionic_doorbell __iomem *db;
-   void *nop_desc;
 };
 
 #define IONIC_INTR_INDEX_NOT_ASSIGNED  (-1)
@@ -257,7 +252,7 @@ uint32_t ionic_cq_service(struct ionic_cq *cq, uint32_t 
work_to_do,
 
 int ionic_q_init(struct ionic_lif *lif, struct ionic_dev *idev,
struct ionic_queue *q, uint32_t index, uint32_t num_descs,
-   size_t desc_size, size_t sg_desc_size, uint32_t pid);
+   size_t desc_size, size_t sg_desc_size);
 void ionic_q_map(struct ionic_queue *q, void *base, rte_iova_t base_pa);
 void ionic_q_sg_map(struct ionic_queue *q, void *base, rte_iova_t base_pa);
 void ionic_q_flush(struct ionic_queue *q);
diff --git a/drivers/net/ionic/ionic_ethdev.c b/drivers/net/ionic/ionic_ethdev.c
index 600333e20..cd79f250e 100644
--- a/drivers/net/ionic/ionic_ethdev.c
+++ b/drivers/net/ionic/ionic_ethdev.c
@@ -1178,8 +1178,6 @@ eth_ionic_pci_probe(struct rte_pci_driver *pci_drv 
__rte_unused,
goto err_free_adapter;
}
 
-   adapter->is_mgmt_nic = (pci_dev->id.device_id == IONIC_DEV_ID_ETH_MGMT);
-
adapter->num_bars = 0;
for (i = 0; i < PCI_MAX_RESOURCE && i < IONIC_BARS_MAX; i++) {
resource = &pci_dev->mem_resource[i];
diff --git a/drivers/net/ionic/ionic_lif.c b/drivers/net/ionic/ionic_lif.c
index 60a5f3d53..bc15d75fd 100644
--- a/drivers/net/ionic/ionic_lif.c
+++ b/drivers/net/ionic/ionic_lif.c
@@ -536,8 +536,6 @@ ionic_lif_change_mtu(struct ionic_lif *lif, int new_mtu)
if (err)
return err;
 
-   lif->mtu = new_mtu;
-
return 0;
 }
 
@@ -583,7 +581,7 @@ ionic_qcq_alloc(struct ionic_lif *lif, uint8_t type,
uint32_t desc_size,
uint32_t cq_desc_size,
uint32_t sg_desc_size,
-   uint32_t pid, struct ionic_qcq **qcq)
+   struct ionic_qcq **qcq)
 {
struct ionic_dev *idev = &lif->adapter->idev;
struct ionic_qcq *new;
@@ -633,7 +631,7 @@ ionic_qcq_alloc(struct ionic_lif *lif, uint8_t type,
new->q.type = type;
 
err = ion

[dpdk-dev] [PATCH v3 3/9] net/ionic: update documentation and MAINTAINERS

2020-12-04 Thread Andrew Boyer
The UNMAINTAINED flag will be removed in a future patch.

Signed-off-by: Andrew Boyer 
---
 MAINTAINERS|  3 ++-
 doc/guides/nics/features/ionic.ini |  2 ++
 doc/guides/nics/ionic.rst  | 13 +++--
 3 files changed, 11 insertions(+), 7 deletions(-)

diff --git a/MAINTAINERS b/MAINTAINERS
index eafe9f8c4..6534983c1 100644
--- a/MAINTAINERS
+++ b/MAINTAINERS
@@ -841,7 +841,8 @@ F: drivers/net/pfe/
 F: doc/guides/nics/features/pfe.ini
 
 Pensando ionic - UNMAINTAINED
-M: Alfredo Cardigliano 
+M: Andrew Boyer 
+M: Pensando Drivers 
 F: drivers/net/ionic/
 F: doc/guides/nics/ionic.rst
 F: doc/guides/nics/features/ionic.ini
diff --git a/doc/guides/nics/features/ionic.ini 
b/doc/guides/nics/features/ionic.ini
index 083c7bd99..dd29dbed6 100644
--- a/doc/guides/nics/features/ionic.ini
+++ b/doc/guides/nics/features/ionic.ini
@@ -8,6 +8,7 @@ Speed capabilities   = Y
 Link status  = Y
 Link status event= Y
 Queue start/stop = Y
+Lock-free Tx queue   = Y
 MTU update   = Y
 Jumbo frame  = Y
 Scattered Rx = Y
@@ -19,6 +20,7 @@ Unicast MAC filter   = Y
 RSS hash = Y
 RSS key update   = Y
 RSS reta update  = Y
+SR-IOV   = Y
 VLAN filter  = Y
 VLAN offload = Y
 Flow control = Y
diff --git a/doc/guides/nics/ionic.rst b/doc/guides/nics/ionic.rst
index fd32926bf..0b78cfbac 100644
--- a/doc/guides/nics/ionic.rst
+++ b/doc/guides/nics/ionic.rst
@@ -1,5 +1,5 @@
 ..  SPDX-License-Identifier: (BSD-3-Clause OR GPL-2.0)
-Copyright(c) 2018-2019 Pensando Systems, Inc. All rights reserved.
+Copyright(c) 2018-2020 Pensando Systems, Inc. All rights reserved.
 
 IONIC Driver
 
@@ -7,15 +7,16 @@ IONIC Driver
 The ionic driver provides support for Pensando server adapters.
 It currently supports the below models:
 
-- `Naples DSC-25 
`_
-- `Naples DSC-100 
`_
+- DSC-25 dual-port 25G Distributed Services Card
+- DSC-100 dual-port 100G Distributed Services Card
 
-Please visit https://pensando.io for more information.
+Please visit the Pensando web site at https://pensando.io for more information.
+The `Documents `_ page contains Product Briefs 
and other product information.
 
 Identifying the Adapter
 ---
 
-To find if one or more Pensando PCI Ethernet devices are installed
+To determine if one or more Pensando DSC Ethernet devices are installed
 on the host, check for the PCI devices:
 
.. code-block:: console
@@ -28,6 +29,6 @@ on the host, check for the PCI devices:
 Building DPDK
 -
 
-The ionic PMD driver supports UIO and VFIO, please refer to the
+The ionic PMD supports UIO and VFIO. Please refer to the
 :ref:`DPDK documentation that comes with the DPDK suite `
 for instructions on how to build DPDK.
-- 
2.17.1



[dpdk-dev] [PATCH v3 6/9] net/ionic: convert 'deferred' boolean to a flag bit

2020-12-04 Thread Andrew Boyer
This conserves resources.

Signed-off-by: Andrew Boyer 
---
 drivers/net/ionic/ionic_lif.c  |  4 ++--
 drivers/net/ionic/ionic_lif.h  |  2 +-
 drivers/net/ionic/ionic_rxtx.c | 10 ++
 3 files changed, 9 insertions(+), 7 deletions(-)

diff --git a/drivers/net/ionic/ionic_lif.c b/drivers/net/ionic/ionic_lif.c
index bc15d75fd..2e33fb8d9 100644
--- a/drivers/net/ionic/ionic_lif.c
+++ b/drivers/net/ionic/ionic_lif.c
@@ -1590,7 +1590,7 @@ ionic_lif_start(struct ionic_lif *lif)
 
for (i = 0; i < lif->nrxqcqs; i++) {
struct ionic_qcq *rxq = lif->rxqcqs[i];
-   if (!rxq->deferred_start) {
+   if (!(rxq->flags & IONIC_QCQ_F_DEFERRED)) {
err = ionic_dev_rx_queue_start(lif->eth_dev, i);
 
if (err)
@@ -1600,7 +1600,7 @@ ionic_lif_start(struct ionic_lif *lif)
 
for (i = 0; i < lif->ntxqcqs; i++) {
struct ionic_qcq *txq = lif->txqcqs[i];
-   if (!txq->deferred_start) {
+   if (!(txq->flags & IONIC_QCQ_F_DEFERRED)) {
err = ionic_dev_tx_queue_start(lif->eth_dev, i);
 
if (err)
diff --git a/drivers/net/ionic/ionic_lif.h b/drivers/net/ionic/ionic_lif.h
index 4e091719f..8e2b42443 100644
--- a/drivers/net/ionic/ionic_lif.h
+++ b/drivers/net/ionic/ionic_lif.h
@@ -50,6 +50,7 @@ struct ionic_rx_stats {
 #define IONIC_QCQ_F_SG BIT(1)
 #define IONIC_QCQ_F_INTR   BIT(2)
 #define IONIC_QCQ_F_NOTIFYQBIT(3)
+#define IONIC_QCQ_F_DEFERRED   BIT(4)
 
 /* Queue / Completion Queue */
 struct ionic_qcq {
@@ -68,7 +69,6 @@ struct ionic_qcq {
uint32_t total_size;
uint32_t flags;
struct ionic_intr_info intr;
-   bool deferred_start;
 };
 
 #define IONIC_Q_TO_QCQ(q)  container_of(q, struct ionic_qcq, q)
diff --git a/drivers/net/ionic/ionic_rxtx.c b/drivers/net/ionic/ionic_rxtx.c
index 2592f5cab..b953aff49 100644
--- a/drivers/net/ionic/ionic_rxtx.c
+++ b/drivers/net/ionic/ionic_rxtx.c
@@ -64,7 +64,7 @@ ionic_txq_info_get(struct rte_eth_dev *dev, uint16_t queue_id,
 
qinfo->nb_desc = q->num_descs;
qinfo->conf.offloads = txq->offloads;
-   qinfo->conf.tx_deferred_start = txq->deferred_start;
+   qinfo->conf.tx_deferred_start = txq->flags & IONIC_QCQ_F_DEFERRED;
 }
 
 static inline void __rte_cold
@@ -196,7 +196,8 @@ ionic_dev_tx_queue_setup(struct rte_eth_dev *eth_dev, 
uint16_t tx_queue_id,
}
 
/* Do not start queue with rte_eth_dev_start() */
-   txq->deferred_start = tx_conf->tx_deferred_start;
+   if (tx_conf->tx_deferred_start)
+   txq->flags |= IONIC_QCQ_F_DEFERRED;
 
txq->offloads = offloads;
 
@@ -605,7 +606,7 @@ ionic_rxq_info_get(struct rte_eth_dev *dev, uint16_t 
queue_id,
qinfo->mp = rxq->mb_pool;
qinfo->scattered_rx = dev->data->scattered_rx;
qinfo->nb_desc = q->num_descs;
-   qinfo->conf.rx_deferred_start = rxq->deferred_start;
+   qinfo->conf.rx_deferred_start = rxq->flags & IONIC_QCQ_F_DEFERRED;
qinfo->conf.offloads = rxq->offloads;
 }
 
@@ -703,7 +704,8 @@ ionic_dev_rx_queue_setup(struct rte_eth_dev *eth_dev,
 */
 
/* Do not start queue with rte_eth_dev_start() */
-   rxq->deferred_start = rx_conf->rx_deferred_start;
+   if (rx_conf->rx_deferred_start)
+   rxq->flags |= IONIC_QCQ_F_DEFERRED;
 
rxq->offloads = offloads;
 
-- 
2.17.1



[dpdk-dev] [PATCH v3 7/9] net/ionic: warn if loopback mode is requested

2020-12-04 Thread Andrew Boyer
The ionic FW does not support loopback mode at this time.

Signed-off-by: Andrew Boyer 
---
 drivers/net/ionic/ionic_ethdev.c | 3 +++
 1 file changed, 3 insertions(+)

diff --git a/drivers/net/ionic/ionic_ethdev.c b/drivers/net/ionic/ionic_ethdev.c
index cd79f250e..ce6ca9671 100644
--- a/drivers/net/ionic/ionic_ethdev.c
+++ b/drivers/net/ionic/ionic_ethdev.c
@@ -919,6 +919,9 @@ ionic_dev_start(struct rte_eth_dev *eth_dev)
return -EINVAL;
}
 
+   if (dev_conf->lpbk_mode)
+   IONIC_PRINT(WARNING, "Loopback mode not supported");
+
err = ionic_lif_start(lif);
if (err) {
IONIC_PRINT(ERR, "Cannot start LIF: %d", err);
-- 
2.17.1



[dpdk-dev] [PATCH v3 8/9] net/ionic: minor refactorings and helper variables

2020-12-04 Thread Andrew Boyer
This makes the code clearer and conserves resources.

Signed-off-by: Andrew Boyer 
---
 drivers/net/ionic/ionic_ethdev.c |  5 ++---
 drivers/net/ionic/ionic_lif.c| 15 ++-
 drivers/net/ionic/ionic_main.c   | 18 +++---
 3 files changed, 19 insertions(+), 19 deletions(-)

diff --git a/drivers/net/ionic/ionic_ethdev.c b/drivers/net/ionic/ionic_ethdev.c
index ce6ca9671..a1c35ace3 100644
--- a/drivers/net/ionic/ionic_ethdev.c
+++ b/drivers/net/ionic/ionic_ethdev.c
@@ -901,7 +901,7 @@ ionic_dev_start(struct rte_eth_dev *eth_dev)
struct ionic_lif *lif = IONIC_ETH_DEV_TO_LIF(eth_dev);
struct ionic_adapter *adapter = lif->adapter;
struct ionic_dev *idev = &adapter->idev;
-   uint32_t allowed_speeds;
+   uint32_t speed, allowed_speeds;
int err;
 
IONIC_PRINT_CALL();
@@ -929,8 +929,7 @@ ionic_dev_start(struct rte_eth_dev *eth_dev)
}
 
if (eth_dev->data->dev_conf.link_speeds & ETH_LINK_SPEED_FIXED) {
-   uint32_t speed = ionic_parse_link_speeds(dev_conf->link_speeds);
-
+   speed = ionic_parse_link_speeds(dev_conf->link_speeds);
if (speed)
ionic_dev_cmd_port_speed(idev, speed);
}
diff --git a/drivers/net/ionic/ionic_lif.c b/drivers/net/ionic/ionic_lif.c
index 2e33fb8d9..722a89565 100644
--- a/drivers/net/ionic/ionic_lif.c
+++ b/drivers/net/ionic/ionic_lif.c
@@ -77,11 +77,14 @@ void
 ionic_lif_reset(struct ionic_lif *lif)
 {
struct ionic_dev *idev = &lif->adapter->idev;
+   int err;
 
IONIC_PRINT_CALL();
 
ionic_dev_cmd_lif_reset(idev, lif->index);
-   ionic_dev_cmd_wait_check(idev, IONIC_DEVCMD_TIMEOUT);
+   err = ionic_dev_cmd_wait_check(idev, IONIC_DEVCMD_TIMEOUT);
+   if (err)
+   IONIC_PRINT(WARNING, "Failed to reset lif");
 }
 
 static void
@@ -305,10 +308,11 @@ ionic_dev_add_mac(struct rte_eth_dev *eth_dev,
 }
 
 void
-ionic_dev_remove_mac(struct rte_eth_dev *eth_dev, uint32_t index __rte_unused)
+ionic_dev_remove_mac(struct rte_eth_dev *eth_dev, uint32_t index)
 {
struct ionic_lif *lif = IONIC_ETH_DEV_TO_LIF(eth_dev);
struct ionic_adapter *adapter = lif->adapter;
+   struct rte_ether_addr *mac_addr;
 
IONIC_PRINT_CALL();
 
@@ -319,11 +323,12 @@ ionic_dev_remove_mac(struct rte_eth_dev *eth_dev, 
uint32_t index __rte_unused)
return;
}
 
-   if (!rte_is_valid_assigned_ether_addr(ð_dev->data->mac_addrs[index]))
+   mac_addr = ð_dev->data->mac_addrs[index];
+
+   if (!rte_is_valid_assigned_ether_addr(mac_addr))
return;
 
-   ionic_lif_addr_del(lif, (const uint8_t *)
-   ð_dev->data->mac_addrs[index]);
+   ionic_lif_addr_del(lif, (const uint8_t *)mac_addr);
 }
 
 int
diff --git a/drivers/net/ionic/ionic_main.c b/drivers/net/ionic/ionic_main.c
index f77bddaa4..92cf0f398 100644
--- a/drivers/net/ionic/ionic_main.c
+++ b/drivers/net/ionic/ionic_main.c
@@ -188,8 +188,7 @@ ionic_adminq_post_wait(struct ionic_lif *lif, struct 
ionic_admin_ctx *ctx)
done = ionic_wait_ctx_for_completion(lif, qcq, ctx,
IONIC_DEVCMD_TIMEOUT);
 
-   err = ionic_adminq_check_err(ctx, !done /* timed out */);
-   return err;
+   return ionic_adminq_check_err(ctx, !done /* timed out */);
 }
 
 static int
@@ -241,10 +240,11 @@ ionic_dev_cmd_wait_check(struct ionic_dev *idev, unsigned 
long max_wait)
int err;
 
err = ionic_dev_cmd_wait(idev, max_wait);
-   if (err)
-   return err;
 
-   return ionic_dev_cmd_check_error(idev);
+   if (!err)
+   err = ionic_dev_cmd_check_error(idev);
+
+   return err;
 }
 
 int
@@ -299,22 +299,18 @@ int
 ionic_init(struct ionic_adapter *adapter)
 {
struct ionic_dev *idev = &adapter->idev;
-   int err;
 
ionic_dev_cmd_init(idev);
-   err = ionic_dev_cmd_wait_check(idev, IONIC_DEVCMD_TIMEOUT);
-   return err;
+   return ionic_dev_cmd_wait_check(idev, IONIC_DEVCMD_TIMEOUT);
 }
 
 int
 ionic_reset(struct ionic_adapter *adapter)
 {
struct ionic_dev *idev = &adapter->idev;
-   int err;
 
ionic_dev_cmd_reset(idev);
-   err = ionic_dev_cmd_wait_check(idev, IONIC_DEVCMD_TIMEOUT);
-   return err;
+   return ionic_dev_cmd_wait_check(idev, IONIC_DEVCMD_TIMEOUT);
 }
 
 int
-- 
2.17.1



[dpdk-dev] [PATCH v3 9/9] net/ionic: minor logging fixups

2020-12-04 Thread Andrew Boyer
Expose ionic_opcode_to_str() so it can be used for dev cmds, too.
Store the device name in struct adapter.

Switch to memcpy() to work around gcc false positives.

Signed-off-by: Andrew Boyer 
---
 drivers/net/ionic/ionic.h |  1 +
 drivers/net/ionic/ionic_dev.c |  5 +++
 drivers/net/ionic/ionic_dev.h |  2 +
 drivers/net/ionic/ionic_ethdev.c  |  4 +-
 drivers/net/ionic/ionic_lif.c | 68 ---
 drivers/net/ionic/ionic_mac_api.c |  4 +-
 drivers/net/ionic/ionic_main.c| 32 ---
 drivers/net/ionic/ionic_rxtx.c| 41 ---
 8 files changed, 84 insertions(+), 73 deletions(-)

diff --git a/drivers/net/ionic/ionic.h b/drivers/net/ionic/ionic.h
index a93110326..7ad0ab69e 100644
--- a/drivers/net/ionic/ionic.h
+++ b/drivers/net/ionic/ionic.h
@@ -48,6 +48,7 @@ struct ionic_hw {
 struct ionic_adapter {
struct ionic_hw hw;
struct ionic_dev idev;
+   const char *name;
struct ionic_dev_bar bars[IONIC_BARS_MAX];
struct ionic_identity   ident;
struct ionic_lif *lifs[IONIC_LIFS_MAX];
diff --git a/drivers/net/ionic/ionic_dev.c b/drivers/net/ionic/ionic_dev.c
index fc68f5c74..f32966521 100644
--- a/drivers/net/ionic/ionic_dev.c
+++ b/drivers/net/ionic/ionic_dev.c
@@ -102,6 +102,9 @@ ionic_dev_cmd_go(struct ionic_dev *idev, union 
ionic_dev_cmd *cmd)
uint32_t cmd_size = sizeof(cmd->words) /
sizeof(cmd->words[0]);
 
+   IONIC_PRINT(DEBUG, "Sending %s (%d) via dev_cmd",
+   ionic_opcode_to_str(cmd->cmd.opcode), cmd->cmd.opcode);
+
for (i = 0; i < cmd_size; i++)
iowrite32(cmd->words[i], &idev->dev_cmd->cmd.words[i]);
 
@@ -348,6 +351,8 @@ ionic_dev_cmd_adminq_init(struct ionic_dev *idev,
.q_init.cq_ring_base = cq->base_pa,
};
 
+   IONIC_PRINT(DEBUG, "adminq.q_init.ver %u", cmd.q_init.ver);
+
ionic_dev_cmd_go(idev, &cmd);
 }
 
diff --git a/drivers/net/ionic/ionic_dev.h b/drivers/net/ionic/ionic_dev.h
index 7150f7f2c..026c4a9f3 100644
--- a/drivers/net/ionic/ionic_dev.h
+++ b/drivers/net/ionic/ionic_dev.h
@@ -205,6 +205,8 @@ struct ionic_qcq;
 void ionic_intr_init(struct ionic_dev *idev, struct ionic_intr_info *intr,
unsigned long index);
 
+const char *ionic_opcode_to_str(enum ionic_cmd_opcode opcode);
+
 int ionic_dev_setup(struct ionic_adapter *adapter);
 
 void ionic_dev_cmd_go(struct ionic_dev *idev, union ionic_dev_cmd *cmd);
diff --git a/drivers/net/ionic/ionic_ethdev.c b/drivers/net/ionic/ionic_ethdev.c
index a1c35ace3..d700aa745 100644
--- a/drivers/net/ionic/ionic_ethdev.c
+++ b/drivers/net/ionic/ionic_ethdev.c
@@ -571,7 +571,7 @@ ionic_dev_rss_reta_update(struct rte_eth_dev *eth_dev,
 
if (reta_size != ident->lif.eth.rss_ind_tbl_sz) {
IONIC_PRINT(ERR, "The size of hash lookup table configured "
-   "(%d) doesn't match the number hardware can supported "
+   "(%d) does not match the number hardware can support "
"(%d)",
reta_size, ident->lif.eth.rss_ind_tbl_sz);
return -EINVAL;
@@ -605,7 +605,7 @@ ionic_dev_rss_reta_query(struct rte_eth_dev *eth_dev,
 
if (reta_size != ident->lif.eth.rss_ind_tbl_sz) {
IONIC_PRINT(ERR, "The size of hash lookup table configured "
-   "(%d) doesn't match the number hardware can supported "
+   "(%d) does not match the number hardware can support "
"(%d)",
reta_size, ident->lif.eth.rss_ind_tbl_sz);
return -EINVAL;
diff --git a/drivers/net/ionic/ionic_lif.c b/drivers/net/ionic/ionic_lif.c
index 722a89565..112bd54fa 100644
--- a/drivers/net/ionic/ionic_lif.c
+++ b/drivers/net/ionic/ionic_lif.c
@@ -84,7 +84,7 @@ ionic_lif_reset(struct ionic_lif *lif)
ionic_dev_cmd_lif_reset(idev, lif->index);
err = ionic_dev_cmd_wait_check(idev, IONIC_DEVCMD_TIMEOUT);
if (err)
-   IONIC_PRINT(WARNING, "Failed to reset lif");
+   IONIC_PRINT(WARNING, "Failed to reset %s", lif->name);
 }
 
 static void
@@ -554,7 +554,7 @@ ionic_intr_alloc(struct ionic_lif *lif, struct 
ionic_intr_info *intr)
/*
 * Note: interrupt handler is called for index = 0 only
 * (we use interrupts for the notifyq only anyway,
-* which hash index = 0)
+* which has index = 0)
 */
 
for (index = 0; index < adapter->nintrs; index++)
@@ -687,8 +687,8 @@ ionic_qcq_alloc(struct ionic_lif *lif, uint8_t type,
ionic_q_sg_map(&new->q, sg_base, sg_base_pa);
}
 
-   IONIC_PRINT(DEBUG, "Q-Base-PA = %ju CQ-Base-PA = %ju "
-   "SG-base-PA = %ju",
+   IONIC_PRINT(DEBUG, "Q-Base-PA = %#jx CQ-Base-PA = %#jx "
+   "SG-base-PA = %#jx",
q_base_pa, cq_base_pa, sg_base_pa);
 
ionic_q_map(&new->q, q_base, 

[dpdk-dev] [PATCH] net/ark: export ark timestamp dynfield offset

2020-12-04 Thread Ed Czeck
Access to mbuf dynfields in application code requires variable
export through header and dynamic library.

Fixes: a926951a606f ("net/ark: switch Rx timestamp to dynamic mbuf field")
Cc: tho...@monjalon.net

Signed-off-by: Ed Czeck 
---
 drivers/net/ark/ark_ethdev.c| 8 
 drivers/net/ark/ark_ethdev_rx.c | 7 ---
 drivers/net/ark/ark_ethdev_rx.h | 3 ---
 drivers/net/ark/rte_pmd_ark.h   | 6 +-
 drivers/net/ark/version.map | 2 ++
 5 files changed, 15 insertions(+), 11 deletions(-)

diff --git a/drivers/net/ark/ark_ethdev.c b/drivers/net/ark/ark_ethdev.c
index a65899351..661fca777 100644
--- a/drivers/net/ark/ark_ethdev.c
+++ b/drivers/net/ark/ark_ethdev.c
@@ -79,8 +79,8 @@ static int  eth_ark_set_mtu(struct rte_eth_dev *dev, uint16_t 
size);
 #define ARK_TX_MAX_QUEUE (4096 * 4)
 #define ARK_TX_MIN_QUEUE (256)
 
-uint64_t ark_timestamp_rx_dynflag;
-int ark_timestamp_dynfield_offset = -1;
+uint64_t rte_pmd_ark_timestamp_rx_dynflag;
+int rte_pmd_ark_timestamp_dynfield_offset = -1;
 
 int rte_pmd_ark_rx_userdata_dynfield_offset = -1;
 int rte_pmd_ark_tx_userdata_dynfield_offset = -1;
@@ -559,8 +559,8 @@ eth_ark_dev_configure(struct rte_eth_dev *dev)
 
if (dev->data->dev_conf.rxmode.offloads & DEV_RX_OFFLOAD_TIMESTAMP) {
ret = rte_mbuf_dyn_rx_timestamp_register(
-   &ark_timestamp_dynfield_offset,
-   &ark_timestamp_rx_dynflag);
+   &rte_pmd_ark_timestamp_dynfield_offset,
+   &rte_pmd_ark_timestamp_rx_dynflag);
if (ret != 0) {
ARK_PMD_LOG(ERR,
"Failed to register Rx timestamp field/flag\n");
diff --git a/drivers/net/ark/ark_ethdev_rx.c b/drivers/net/ark/ark_ethdev_rx.c
index d29d3db78..2021e33d0 100644
--- a/drivers/net/ark/ark_ethdev_rx.c
+++ b/drivers/net/ark/ark_ethdev_rx.c
@@ -273,10 +273,11 @@ eth_ark_recv_pkts(void *rx_queue,
mbuf->pkt_len = meta->pkt_len;
mbuf->data_len = meta->pkt_len;
/* set timestamp if enabled at least on one device */
-   if (ark_timestamp_rx_dynflag > 0) {
-   *RTE_MBUF_DYNFIELD(mbuf, ark_timestamp_dynfield_offset,
+   if (rte_pmd_ark_timestamp_rx_dynflag > 0) {
+   *RTE_MBUF_DYNFIELD(mbuf,
+   rte_pmd_ark_timestamp_dynfield_offset,
rte_mbuf_timestamp_t *) = meta->timestamp;
-   mbuf->ol_flags |= ark_timestamp_rx_dynflag;
+   mbuf->ol_flags |= rte_pmd_ark_timestamp_rx_dynflag;
}
rte_pmd_ark_mbuf_rx_userdata_set(mbuf, meta->user_data);
 
diff --git a/drivers/net/ark/ark_ethdev_rx.h b/drivers/net/ark/ark_ethdev_rx.h
index 001fa9bdf..00687a711 100644
--- a/drivers/net/ark/ark_ethdev_rx.h
+++ b/drivers/net/ark/ark_ethdev_rx.h
@@ -11,9 +11,6 @@
 #include 
 #include 
 
-extern uint64_t ark_timestamp_rx_dynflag;
-extern int ark_timestamp_dynfield_offset;
-
 int eth_ark_dev_rx_queue_setup(struct rte_eth_dev *dev,
   uint16_t queue_idx,
   uint16_t nb_desc,
diff --git a/drivers/net/ark/rte_pmd_ark.h b/drivers/net/ark/rte_pmd_ark.h
index 6f26d66b1..55be29fc5 100644
--- a/drivers/net/ark/rte_pmd_ark.h
+++ b/drivers/net/ark/rte_pmd_ark.h
@@ -27,6 +27,9 @@ typedef uint64_t rte_pmd_ark_rx_userdata_t;
 extern int rte_pmd_ark_tx_userdata_dynfield_offset;
 extern int rte_pmd_ark_rx_userdata_dynfield_offset;
 
+extern int rte_pmd_ark_timestamp_dynfield_offset;
+extern uint64_t rte_pmd_ark_timestamp_rx_dynflag;
+
 /** mbuf dynamic field for custom Tx ARK data */
 #define RTE_PMD_ARK_TX_USERDATA_DYNFIELD_NAME 
"rte_net_ark_dynfield_tx_userdata"
 /** mbuf dynamic field for custom Rx ARK data */
@@ -46,7 +49,8 @@ static inline rte_pmd_ark_tx_userdata_t
 rte_pmd_ark_mbuf_tx_userdata_get(const struct rte_mbuf *mbuf)
 {
 #if RTE_PMD_ARK_TX_USERDATA_ENABLE
-   return *RTE_MBUF_DYNFIELD(mbuf, rte_pmd_ark_tx_userdata_dynfield_offset,
+   return *RTE_MBUF_DYNFIELD(mbuf,
+ rte_pmd_ark_tx_userdata_dynfield_offset,
  rte_pmd_ark_tx_userdata_t *);
 #else
RTE_SET_USED(mbuf);
diff --git a/drivers/net/ark/version.map b/drivers/net/ark/version.map
index 954bea679..8da6771d0 100644
--- a/drivers/net/ark/version.map
+++ b/drivers/net/ark/version.map
@@ -7,4 +7,6 @@ EXPERIMENTAL {
 
rte_pmd_ark_tx_userdata_dynfield_offset;
rte_pmd_ark_rx_userdata_dynfield_offset;
+   rte_pmd_ark_timestamp_dynfield_offset;
+   rte_pmd_ark_timestamp_rx_dynflag;
 };
-- 
2.17.1



Re: [dpdk-dev] [PATCH] net/ark: export ark timestamp dynfield offset

2020-12-04 Thread Stephen Hemminger
On Fri,  4 Dec 2020 15:27:45 -0500
Ed Czeck  wrote:

> Access to mbuf dynfields in application code requires variable
> export through header and dynamic library.
> 
> Fixes: a926951a606f ("net/ark: switch Rx timestamp to dynamic mbuf field")
> Cc: tho...@monjalon.net
> 
> Signed-off-by: Ed Czeck 

Not happy with having offsets exposed from driver.

Expopsing weird offsets for their special fields
is worse than the old model.

Why not use standardized field name and have the application lookup that?
There is an API already for that.



Re: [dpdk-dev] [PATCH v2] eal/windows: vfprintf build warning with clang

2020-12-04 Thread Kadam, Pallavi



On 11/29/2020 5:00 AM, Nick Connolly wrote:

When building with clang (11.0,--buildtype=debug), eal_lcore.c
produces a -Wformat-nonliteral warning from the vfprintf call
in log_early.

Add __rte_format_printf annotation.

Fixes: b8a36b086625 ("eal/windows: improve CPU and NUMA node detection")
Cc: sta...@dpdk.org

Signed-off-by: Nick Connolly 
Suggested-by: Dmitry Kozlyuk 
---

Acked-by: Pallavi Kadam 


Re: [dpdk-dev] [PATCH v2] windows: build warnings with clang

2020-12-04 Thread Kadam, Pallavi

Hi Nick,

Thanks for this patch. Could not see the deprecated warnings anymore.

On 11/29/2020 8:00 AM, Nick Connolly wrote:

Microsoft CRT defines Windows-specific secure alternatives to
standard library functions and triggers warnings when "insecure"
functions are used [1]. However, calling code already has all
necessary checks around those functions, so these warnings are not
useful for DPDK. MinGW provides its own CRT without this issue.

[1]:
https://docs.microsoft.com/en-us/cpp/c-runtime-library/security-features-in-the-crt?view=msvc-160

Disable this by defining -D_CRT_SECURE_NO_WARNINGS.

Signed-off-by: Nick Connolly 
---

Acked-by: Pallavi Kadam 


Re: [dpdk-dev] [PATCH] eal/windows: add stub for rte_intr_callback_register

2020-12-04 Thread Kadam, Pallavi

Hi Tal,

On 11/26/2020 12:06 AM, Tal Shnaiderman wrote:

interrupt callback register is not implemented in Windows.
Add stub with -ENOTSUP return value and export the function.

Signed-off-by: Tal Shnaiderman 
---
  lib/librte_eal/rte_eal_exports.def  | 1 +
  lib/librte_eal/windows/eal_interrupts.c | 9 +
  2 files changed, 10 insertions(+)

diff --git a/lib/librte_eal/rte_eal_exports.def 
b/lib/librte_eal/rte_eal_exports.def
index 6a6be1cfa6..08cf25ea01 100644
--- a/lib/librte_eal/rte_eal_exports.def
+++ b/lib/librte_eal/rte_eal_exports.def
@@ -63,6 +63,7 @@ EXPORTS
rte_get_tsc_hz
rte_hexdump
rte_hypervisor_get
+   rte_intr_callback_register
rte_intr_rx_ctl
rte_lcore_count
rte_lcore_has_role
diff --git a/lib/librte_eal/windows/eal_interrupts.c 
b/lib/librte_eal/windows/eal_interrupts.c
index 6c64a48f34..fea338d705 100644
--- a/lib/librte_eal/windows/eal_interrupts.c
+++ b/lib/librte_eal/windows/eal_interrupts.c
@@ -105,3 +105,12 @@ eal_intr_thread_schedule(void (*func)(void *arg), void 
*arg)
  
  	return 0;

  }
+
+int
+rte_intr_callback_register(
+   __rte_unused const struct rte_intr_handle *intr_handle,
+   __rte_unused rte_intr_callback_fn cb,
+   __rte_unused void *cb_arg)
+{
+   return -ENOTSUP;
+}


We have also included the same code as it is required to compile i40e PMD.

Will remove it from our patch once this code is merged.

Thanks,




Re: [dpdk-dev] [PATCH] eal/windows: add stub for rte_intr_callback_register

2020-12-04 Thread Kadam, Pallavi



On 11/26/2020 12:06 AM, Tal Shnaiderman wrote:

interrupt callback register is not implemented in Windows.
Add stub with -ENOTSUP return value and export the function.

Signed-off-by: Tal Shnaiderman 
---

Acked-by: Pallavi Kadam 


[dpdk-dev] [PATCH 0/3] Support i40e PMD on Windows

2020-12-04 Thread Pallavi Kadam
This patch-set enables building the Intel i40e PMD on Windows.
It also adds a compiler flag to ignore a few warnings generated
when compiling the code on Windows.


Pallavi Kadam (3):
  eal/windows: add some interrupt functions stub
  net/i40e: add changes to support i40e PMD on windows
  config/build: ignore enum forward reference warning

 config/meson.build   |  3 +
 drivers/net/i40e/base/i40e_osdep.h   |  3 +
 drivers/net/i40e/i40e_ethdev_vf.c|  3 +-
 drivers/net/i40e/i40e_rxtx_vec_avx2.c|  2 +
 drivers/net/i40e/i40e_tm.c   |  2 +-
 drivers/net/meson.build  |  9 ++-
 lib/librte_eal/common/meson.build|  1 +
 lib/librte_eal/rte_eal_exports.def   | 11 +++
 lib/librte_eal/windows/eal_interrupts.c  | 70 
 lib/librte_eal/windows/include/rte_windows.h |  5 ++
 10 files changed, 104 insertions(+), 5 deletions(-)

-- 
2.18.0.windows.1



[dpdk-dev] [PATCH 3/3] config/build: ignore enum forward reference warning

2020-12-04 Thread Pallavi Kadam
Warning generated using Clang compiler:
..\drivers\net\i40e\base/i40e_osdep.h:34:14: warning: forward references
to 'enum' types are a Microsoft extension
[-Wmicrosoft-enum-forward-reference]
typedef enum i40e_status_code i40e_status;
 ^

Adding -Wmicrosoft-enum-forward-reference compiler flag to disable
the warning on Windows Clang.

Signed-off-by: Pallavi Kadam 
Reviewed-by: Ranjit Menon 
---
 config/meson.build | 3 +++
 1 file changed, 3 insertions(+)

diff --git a/config/meson.build b/config/meson.build
index c02802c18..6736023fa 100644
--- a/config/meson.build
+++ b/config/meson.build
@@ -212,6 +212,9 @@ warning_flags = [
'-Wno-packed-not-aligned',
'-Wno-missing-field-initializers'
 ]
+if is_windows
+   warning_flags += '-Wno-microsoft-enum-forward-reference'
+endif
 if cc.get_id() == 'gcc' and cc.version().version_compare('>=10.0')
 # FIXME: Bugzilla 396
warning_flags += '-Wno-zero-length-bounds'
-- 
2.18.0.windows.1



[dpdk-dev] [PATCH 2/3] net/i40e: add changes to support i40e PMD on windows

2020-12-04 Thread Pallavi Kadam
Adding build changes to compile i40e PMD on windows.
Disabling few warnings with Clang such as comparison of integers of
different signs and macro redefinitions.
Also, adding linking dependency source file rte_random.c file to
Windows.

Signed-off-by: Pallavi Kadam 
Reviewed-by: Ranjit Menon 
---
 drivers/net/i40e/base/i40e_osdep.h   | 3 +++
 drivers/net/i40e/i40e_ethdev_vf.c| 3 ++-
 drivers/net/i40e/i40e_rxtx_vec_avx2.c| 2 ++
 drivers/net/i40e/i40e_tm.c   | 2 +-
 drivers/net/meson.build  | 9 ++---
 lib/librte_eal/common/meson.build| 1 +
 lib/librte_eal/rte_eal_exports.def   | 1 +
 lib/librte_eal/windows/include/rte_windows.h | 5 +
 8 files changed, 21 insertions(+), 5 deletions(-)

diff --git a/drivers/net/i40e/base/i40e_osdep.h 
b/drivers/net/i40e/base/i40e_osdep.h
index 9b5033024..fa22df122 100644
--- a/drivers/net/i40e/base/i40e_osdep.h
+++ b/drivers/net/i40e/base/i40e_osdep.h
@@ -67,8 +67,11 @@ typedef enum i40e_status_code i40e_status;
 #define false   0
 #define true1
 
+/* Avoid macro redifinition warning on Windows */
+#ifndef RTE_EXEC_ENV_WINDOWS
 #define min(a,b) RTE_MIN(a,b)
 #define max(a,b) RTE_MAX(a,b)
+#endif
 
 #define FIELD_SIZEOF(t, f) (sizeof(((t*)0)->f))
 
diff --git a/drivers/net/i40e/i40e_ethdev_vf.c 
b/drivers/net/i40e/i40e_ethdev_vf.c
index c26b036b8..daf4a3f99 100644
--- a/drivers/net/i40e/i40e_ethdev_vf.c
+++ b/drivers/net/i40e/i40e_ethdev_vf.c
@@ -1495,7 +1495,8 @@ i40evf_handle_aq_msg(struct rte_eth_dev *dev)
   info.msg_len);
else {
/* read message and it's expected one */
-   if (msg_opc == vf->pend_cmd) {
+   if ((volatile uint32_t)msg_opc ==
+   vf->pend_cmd) {
vf->cmd_retval = msg_ret;
/* prevent compiler reordering */
rte_compiler_barrier();
diff --git a/drivers/net/i40e/i40e_rxtx_vec_avx2.c 
b/drivers/net/i40e/i40e_rxtx_vec_avx2.c
index 7a558fc73..cf2dc88c5 100644
--- a/drivers/net/i40e/i40e_rxtx_vec_avx2.c
+++ b/drivers/net/i40e/i40e_rxtx_vec_avx2.c
@@ -12,7 +12,9 @@
 #include "i40e_rxtx.h"
 #include "i40e_rxtx_vec_common.h"
 
+#ifndef RTE_EXEC_ENV_WINDOWS
 #include 
+#endif
 
 #ifndef __INTEL_COMPILER
 #pragma GCC diagnostic ignored "-Wcast-qual"
diff --git a/drivers/net/i40e/i40e_tm.c b/drivers/net/i40e/i40e_tm.c
index 5d722f92c..cab296e1a 100644
--- a/drivers/net/i40e/i40e_tm.c
+++ b/drivers/net/i40e/i40e_tm.c
@@ -554,7 +554,7 @@ i40e_node_add(struct rte_eth_dev *dev, uint32_t node_id,
}
/* check level */
if (level_id != RTE_TM_NODE_LEVEL_ID_ANY &&
-   level_id != parent_node_type + 1) {
+   level_id != (uint32_t)parent_node_type + 1) {
error->type = RTE_TM_ERROR_TYPE_NODE_PARAMS;
error->message = "Wrong level";
return -EINVAL;
diff --git a/drivers/net/meson.build b/drivers/net/meson.build
index 29f477750..b3bc0277e 100644
--- a/drivers/net/meson.build
+++ b/drivers/net/meson.build
@@ -1,9 +1,6 @@
 # SPDX-License-Identifier: BSD-3-Clause
 # Copyright(c) 2017 Intel Corporation
 
-if is_windows
-   subdir_done()
-endif
 
 drivers = ['af_packet',
'af_xdp',
@@ -56,6 +53,12 @@ drivers = ['af_packet',
'virtio',
'vmxnet3',
 ]
+
+if is_windows
+   drivers = ['i40e',
+   ]
+endif
+
 std_deps = ['ethdev', 'kvargs'] # 'ethdev' also pulls in mbuf, net, eal etc
 std_deps += ['bus_pci'] # very many PMDs depend on PCI, so make std
 std_deps += ['bus_vdev']# same with vdev bus
diff --git a/lib/librte_eal/common/meson.build 
b/lib/librte_eal/common/meson.build
index 39abf7a0a..98e8fffd4 100644
--- a/lib/librte_eal/common/meson.build
+++ b/lib/librte_eal/common/meson.build
@@ -33,6 +33,7 @@ if is_windows
'malloc_heap.c',
'rte_malloc.c',
'eal_common_timer.c',
+   'rte_random.c',
'rte_service.c',
)
subdir_done()
diff --git a/lib/librte_eal/rte_eal_exports.def 
b/lib/librte_eal/rte_eal_exports.def
index 89166acd7..428201872 100644
--- a/lib/librte_eal/rte_eal_exports.def
+++ b/lib/librte_eal/rte_eal_exports.def
@@ -124,6 +124,7 @@ EXPORTS
rte_memzone_reserve_bounded
rte_memzone_walk
rte_openlog_stream
+   rte_rand
rte_realloc
rte_rtm_supported
rte_service_attr_get
diff --git a/lib/librte_eal/windows/include/rte_windows.h 
b/lib/librte_eal/windows/include/rte_windows.h
index b82af34f6..822922c11 100644
--- a/lib/librte_eal/windows/include/rte_windows.h
+++ b/lib/librte_eal/windows/include/rte_windows.h
@@ -18,6 +18,11 @@
 #define WIN32_LEAN_AND_MEAN
 #endif
 
+#ifdef __clang__
+#undef _m_pr

[dpdk-dev] [PATCH 1/3] eal/windows: add some interrupt functions stub

2020-12-04 Thread Pallavi Kadam
Adding some interrupt implementations on Windows to help compile
i40e PMD code.
Also added respective functions to export file.

Signed-off-by: Pallavi Kadam 
Reviewed-by: Ranjit Menon 
---
 lib/librte_eal/rte_eal_exports.def  | 10 
 lib/librte_eal/windows/eal_interrupts.c | 70 +
 2 files changed, 80 insertions(+)

diff --git a/lib/librte_eal/rte_eal_exports.def 
b/lib/librte_eal/rte_eal_exports.def
index 6a6be1cfa..89166acd7 100644
--- a/lib/librte_eal/rte_eal_exports.def
+++ b/lib/librte_eal/rte_eal_exports.def
@@ -63,6 +63,16 @@ EXPORTS
rte_get_tsc_hz
rte_hexdump
rte_hypervisor_get
+   rte_intr_ack
+   rte_intr_allow_others
+   rte_intr_callback_register
+   rte_intr_callback_unregister
+   rte_intr_cap_multiple
+   rte_intr_disable
+   rte_intr_dp_is_en
+   rte_intr_efd_disable
+   rte_intr_efd_enable
+   rte_intr_enable
rte_intr_rx_ctl
rte_lcore_count
rte_lcore_has_role
diff --git a/lib/librte_eal/windows/eal_interrupts.c 
b/lib/librte_eal/windows/eal_interrupts.c
index 6c64a48f3..f6c24787f 100644
--- a/lib/librte_eal/windows/eal_interrupts.c
+++ b/lib/librte_eal/windows/eal_interrupts.c
@@ -105,3 +105,73 @@ eal_intr_thread_schedule(void (*func)(void *arg), void 
*arg)
 
return 0;
 }
+
+int
+rte_intr_callback_register(
+   __rte_unused const struct rte_intr_handle *intr_handle,
+   __rte_unused rte_intr_callback_fn cb, __rte_unused void *cb_arg)
+{
+   return -ENOTSUP;
+}
+
+int
+rte_intr_callback_unregister(
+   __rte_unused const struct rte_intr_handle *intr_handle,
+   __rte_unused rte_intr_callback_fn cb_fn, __rte_unused void *cb_arg)
+{
+   return 0;
+}
+
+int
+rte_intr_enable(__rte_unused const struct rte_intr_handle *intr_handle)
+{
+   return -ENOTSUP;
+}
+
+int
+rte_intr_ack(__rte_unused const struct rte_intr_handle *intr_handle)
+{
+   return -ENOTSUP;
+}
+
+int
+rte_intr_disable(__rte_unused const struct rte_intr_handle *intr_handle)
+{
+   return -ENOTSUP;
+}
+
+int
+rte_intr_efd_enable(struct rte_intr_handle *intr_handle, uint32_t nb_efd)
+{
+   RTE_SET_USED(intr_handle);
+   RTE_SET_USED(nb_efd);
+
+   return 0;
+}
+
+void
+rte_intr_efd_disable(struct rte_intr_handle *intr_handle)
+{
+   RTE_SET_USED(intr_handle);
+}
+
+int
+rte_intr_dp_is_en(struct rte_intr_handle *intr_handle)
+{
+   RTE_SET_USED(intr_handle);
+   return 0;
+}
+
+int
+rte_intr_allow_others(struct rte_intr_handle *intr_handle)
+{
+   RTE_SET_USED(intr_handle);
+   return 1;
+}
+
+int
+rte_intr_cap_multiple(struct rte_intr_handle *intr_handle)
+{
+   RTE_SET_USED(intr_handle);
+   return 0;
+}
-- 
2.18.0.windows.1



Re: [dpdk-dev] [PATCH] app/testpmd: fix IP checksum calculation

2020-12-04 Thread George Prekas



On 12/4/2020 2:59 AM, Ferruh Yigit wrote:
CAUTION: This email originated from outside of the organization. Do 
not click links or open attachments unless you can confirm the sender 
and know the content is safe.




On 12/3/2020 1:59 PM, George Prekas wrote:

Insert a compiler barrier to make sure that the IP checksum calculation
happens after setting all the fields of the IP header.



Can you please provide the compiler details, and if there is any specific
instruction on how to reproduce this failure?


This happens with GCC 9 and GCC 10. It works fine on GCC 8.

Stephen was right that a compiler barrier here is not the right 
solution. After spending some time on it, I realized that it is an 
aliasing problem when casting the IP header to uint16_t*. As far as I 
understand, this is not allowed by the C standard. As far as I know, 
there are 3 ways to fix this problem: Use a union, use memcpy, or set 
the compiler flag -fno-strict-aliasing. I assume that the last option is 
the least intrusive. I've submitted a second version of the patch with it.


Let me know of your opinion.




Signed-off-by: George Prekas 
---
  app/test-pmd/flowgen.c | 1 +
  1 file changed, 1 insertion(+)

diff --git a/app/test-pmd/flowgen.c b/app/test-pmd/flowgen.c
index acf3e2460..893b4b0b8 100644
--- a/app/test-pmd/flowgen.c
+++ b/app/test-pmd/flowgen.c
@@ -150,6 +150,7 @@ pkt_burst_flow_gen(struct fwd_stream *fs)
next_flow);
  ip_hdr->total_length    = RTE_CPU_TO_BE_16(pkt_size -
sizeof(*eth_hdr));
+ rte_compiler_barrier();
  ip_hdr->hdr_checksum    = ip_sum((unaligned_uint16_t 
*)ip_hdr,

   sizeof(*ip_hdr));
-- 
2.17.1



[dpdk-dev] [PATCH v3 2/9] net/ionic: update interface file to the latest version

2020-12-04 Thread Andrew Boyer
The ionic_if.h file contains the firmware interface definitions.

Signed-off-by: Andrew Boyer 
---
 drivers/net/ionic/ionic_if.h   | 1343 ++--
 drivers/net/ionic/ionic_regs.h |3 -
 2 files changed, 930 insertions(+), 416 deletions(-)

diff --git a/drivers/net/ionic/ionic_if.h b/drivers/net/ionic/ionic_if.h
index f83c8711b..ba4cc4b72 100644
--- a/drivers/net/ionic/ionic_if.h
+++ b/drivers/net/ionic/ionic_if.h
@@ -1,17 +1,15 @@
 /* SPDX-License-Identifier: GPL-2.0 OR Linux-OpenIB OR BSD-3-Clause */
-/* Copyright (c) 2017-2019 Pensando Systems, Inc.  All rights reserved. */
+/* Copyright (c) 2017-2020 Pensando Systems, Inc.  All rights reserved. */
 
 #ifndef _IONIC_IF_H_
 #define _IONIC_IF_H_
 
-#pragma pack(push, 1)
-
 #define IONIC_DEV_INFO_SIGNATURE   0x44455649  /* 'DEVI' */
 #define IONIC_DEV_INFO_VERSION 1
 #define IONIC_IFNAMSIZ 16
 
 /**
- * Commands
+ * enum ionic_cmd_opcode - Device commands
  */
 enum ionic_cmd_opcode {
IONIC_CMD_NOP   = 0,
@@ -42,6 +40,7 @@ enum ionic_cmd_opcode {
IONIC_CMD_RX_FILTER_DEL = 32,
 
/* Queue commands */
+   IONIC_CMD_Q_IDENTIFY= 39,
IONIC_CMD_Q_INIT= 40,
IONIC_CMD_Q_CONTROL = 41,
 
@@ -51,10 +50,17 @@ enum ionic_cmd_opcode {
IONIC_CMD_RDMA_CREATE_CQ= 52,
IONIC_CMD_RDMA_CREATE_ADMINQ= 53,
 
+   /* SR/IOV commands */
+   IONIC_CMD_VF_GETATTR= 60,
+   IONIC_CMD_VF_SETATTR= 61,
+
/* QoS commands */
IONIC_CMD_QOS_CLASS_IDENTIFY= 240,
IONIC_CMD_QOS_CLASS_INIT= 241,
IONIC_CMD_QOS_CLASS_RESET   = 242,
+   IONIC_CMD_QOS_CLASS_UPDATE  = 243,
+   IONIC_CMD_QOS_CLEAR_STATS   = 244,
+   IONIC_CMD_QOS_RESET = 245,
 
/* Firmware commands */
IONIC_CMD_FW_DOWNLOAD   = 254,
@@ -62,7 +68,7 @@ enum ionic_cmd_opcode {
 };
 
 /**
- * Command Return codes
+ * enum ionic_status_code - Device command return codes
  */
 enum ionic_status_code {
IONIC_RC_SUCCESS= 0,/* Success */
@@ -86,8 +92,8 @@ enum ionic_status_code {
IONIC_RC_DEV_CMD= 18,   /* Device cmd attempted on AdminQ */
IONIC_RC_ENOSUPP= 19,   /* Operation not supported */
IONIC_RC_ERROR  = 29,   /* Generic error */
-
IONIC_RC_ERDMA  = 30,   /* Generic RDMA error */
+   IONIC_RC_EVFID  = 31,   /* VF ID does not exist */
 };
 
 enum ionic_notifyq_opcode {
@@ -95,10 +101,11 @@ enum ionic_notifyq_opcode {
IONIC_EVENT_RESET   = 2,
IONIC_EVENT_HEARTBEAT   = 3,
IONIC_EVENT_LOG = 4,
+   IONIC_EVENT_XCVR= 5,
 };
 
 /**
  * struct cmd - General admin command format
  * @opcode: Opcode for the command
  * @lif_index:  LIF index
  * @cmd_data:   Opcode-specific command bytes
@@ -112,12 +119,11 @@ struct ionic_admin_cmd {
 
 /**
  * struct ionic_admin_comp - General admin command completion format
  * @status: The status of the command (enum status_code)
  * @comp_index: The index in the descriptor ring for which this
  *  is the completion.
  * @cmd_data:   Command-specific bytes.
  * @color:  Color bit.  (Always 0 for commands issued to the
  *  Device Cmd Registers.)
  */
 struct ionic_admin_comp {
u8 status;
@@ -144,7 +150,7 @@ struct ionic_nop_cmd {
 
 /**
  * struct ionic_nop_comp - NOP command completion
  * @status: The status of the command (enum status_code)
  */
 struct ionic_nop_comp {
u8 status;
@@ -154,7 +160,7 @@ struct ionic_nop_comp {
 /**
  * struct ionic_dev_init_cmd - Device init command
  * @opcode:opcode
- * @type:  device type
+ * @type:  Device type
  */
 struct ionic_dev_init_cmd {
u8 opcode;
@@ -163,8 +169,8 @@ struct ionic_dev_init_cmd {
 };
 
 /**
  * struct init_comp - Device init command completion
  * @status: The status of the command (enum status_code)
  */
 struct ionic_dev_init_comp {
u8 status;
@@ -181,8 +187,8 @@ struct ionic_dev_reset_cmd {
 };
 
 /**
- * struct reset_comp - Reset command completion
- * @status: The status of the command (enum stat

[dpdk-dev] [PATCH v3 4/9] net/ionic: check for cmd completion more frequently

2020-12-04 Thread Andrew Boyer
This reduces the startup time a bit.

Signed-off-by: Neel Patel 
Signed-off-by: Andrew Boyer 
---
 drivers/net/ionic/ionic_dev.h   |  4 +++-
 drivers/net/ionic/ionic_main.c  | 36 -
 drivers/net/ionic/ionic_osdep.h | 10 -
@@ -95,10 +101,11 @@ enum ionic_notifyq_opcode {
 
 /**
- * struct cmd - General admin command format
+ * struct ionic_admin_cmd - General admin command format
  * @opcode: Opcode for the command
  * @lif_index:  LIF index
@@ -112,12 +119,11 @@ struct ionic_admin_cmd {
 /**
  * struct ionic_admin_comp - General admin command completion format
- * @status: The status of the command (enum status_code)
- * @comp_index: The index in the descriptor ring for which this
- *  is the completion.
- * @cmd_data:   Command-specific bytes.
- * @color:  Color bit.  (Always 0 for commands issued to the
- *  Device Cmd Registers.)
+ * @status: Status of the command (enum ionic_status_code)
+ * @comp_index: Index in the descriptor ring for which this is the completion
+ * @cmd_data:   Command-specific bytes
+ * @color:  Color bit (Always 0 for commands issued to the
+ *  Device Cmd Registers)
  */
 struct ionic_admin_comp {
@@ -144,7 +150,7 @@ struct ionic_nop_cmd {
 /**
  * struct ionic_nop_comp - NOP command completion
- * @status: The status of the command (enum status_code)
+ * @status: Status of the command (enum ionic_status_code)
  */
 struct ionic_nop_comp {
@@ -163,8 +169,8 @@ struct ionic_dev_init_cmd {
 
 /**
- * struct init_comp - Device init command completion
- * @status: The status of the command (enum status_code)
+ * struct ionic_dev_init_comp - Device init command completion
+ * @status: Status of the command (enum ionic_status_code)
  */
 struct ionic_dev_init_comp {
 3 files changed, 21 insertions(+), 29 deletions(-)
